All Classes and Interfaces
Class
Description
The
AckTimeout defines values used inside a Transmit/Acknowledge
(ARQ) processing control flow.Commonly used characters to be prefixed to annotations' names to distinguish
them form element names and the like.
This enumeration contains ANSI Escape-Codes for modifying the appearance of
console output to ANSI enabled terminals.
Some ASCII codes used by REFCODES.ORG artifacts.
An enumeration for text palette definitions to make it easy working with such
default palettes.
Some values regarding binary numbers.
The Enum BitMask.
Some values's literal (
String) representation useful when parsing or
evaluating texts.Commonly used char sets.
Commonly used prefixes needful for analyzing, parsing or truncating command
line arguments and so on.
This enumeration groups
CommandArgPrefix by platform.The Enum ConsoleDimension.
The
DaemonLoopSleepTime defined values used inside a control flow.Provides an accessor for a data locators property (array of
URLs and
InputStreams).Provides a builder for a data locators property.
Provides a mutator for a data locators property.
Provides a property (getter / setter) for a data locators property (width
and height).
Provides an accessor for a data locator property (
URL and
InputStream).Provides a builder for a data locator property.
Provides a mutator for a data locator property.
Provides a property (getter / setter) for a data locator property (width
and height).
Commonly used characters when working with separated values or properties and
the like making use of text separator characters .
The
Delimiters groups Delimiter values belonging somehow
together or sharing a similar semantics.The
Encoding define values representing an encoding which are to be
passed as argument to according methods.Commonly used characters for EOL markers in texts.
EnvironmentVariable for retrieving some common environment variables
with ease.The
EscapeCode enumeration contains all of Java's escape codes
(https://docs.oracle.com/javase/tutorial/java/data/characters.html) and the
escape sequences (being the defused escape codes) as well as methods to
retrieve the escape code from the escape sequence (as of
EscapeCode.toEscapeCode(String)) and vice versa (as of
EscapeCode.toEscapeCode(char)).Some default exit codes defined for CLI applications.
The
FilenameExtension define values useful when working with files or
a file-system.A flag can be on or off.
The
Folder define values useful when working with files or a
file-system.The
Folders define values useful when working with folders on a
file-system.The
IoBlockSize defined values used inside a control flow.The
IoHeurisitcsTimeToLive defines values used to cache IO related
heuristics (e.g. meta data of or for remote systems)The
IoPollLoopTime defined values used when polling data from I/O,
e.g. the file system or via TCP/IP.The
IoReconnectLoopTime defined values used inside a control flow.The
IoRetryCount defined values used inside a control flow.The
IoSleepLoopTime defined values used inside a control flow.The
IoTimeout defines values used inside a IO processing control
flow.The
LatencySleepTime defined values used inside a control flow.Some licensing and copyright information as
String constants.Some values's literal (
String) representation useful when parsing or
evaluating texts.The
LoopExtensionTime defined values used inside a control flow.MarshalParameter defines common parameters (parameter is considered
the key of a key/value pair) of a given semantics for the according property.The
MemoryUnit provides enumerations for common memory units
alongside conversions to and from memory size specified in bytes.Commonly used characters needful for analyzing, parsing or truncating texts.
The
Numbers interface defines some constants of interest related to
the various number types available.Commonly used characters needful for analyzing, parsing or truncating texts.
The Enum Port.
Commonly used prefixes needful for analyzing, parsing or truncating texts the
like.
Commonly used characters needful for analyzing, parsing or truncating texts.
A text region has a beginning index being included by the region and an end
index being excluded by the region and a resulting length.
The
RetryCount defined values used inside a control flow.The
RetryLoopCount defined values used inside a control flow.The
ScheduleSleepTime defined values used inside a control flow.The
Scheme define values useful when working with files or a
file-system.Defines enumeration elements for the left and the right side.
The
SleepLoopTime defined values used inside a control flow.Commonly used characters needful for analyzing, parsing or truncating texts.
SystemProperty define values to be used at runtime.Commonly used text blocks in the code.
The Enum TextBorder.
Commonly used characters needful for analyzing, parsing or truncating texts.