Constant Field Values
Contents
org.refcodes.*
-
org.refcodes.data.IoTimeout Modifier and Type Constant Field Value public static final intTIMEOUT_DIVIDER64 -
org.refcodes.data.Numbers Modifier and Type Constant Field Value public static final longMAX_SAFE_INTEGER9007199254740991Lpublic static final longMIN_SAFE_INTEGER-9007199254740992Lpublic static final intSAFE_INTEGER_BYTES7