Enum AckTimeout

java.lang.Object
java.lang.Enum<AckTimeout>
org.refcodes.data.AckTimeout
All Implemented Interfaces:
Serializable, Comparable<AckTimeout>, java.lang.constant.Constable, org.refcodes.mixin.TimeInMsAccessor

public enum AckTimeout
extends Enum<AckTimeout>
implements org.refcodes.mixin.TimeInMsAccessor
The AckTimeout defines values used inside a Transmit/Acknowledge (ARQ) processing control flow.
  • Nested Class Summary

    Nested classes/interfaces inherited from class java.lang.Enum

    Enum.EnumDesc<E extends Enum<E>>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.TimeInMsAccessor

    org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B extends org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B>>, org.refcodes.mixin.TimeInMsAccessor.TimeInMsMutator, org.refcodes.mixin.TimeInMsAccessor.TimeInMsProperty
  • Enum Constant Summary

    Enum Constants
    Enum Constant Description
    MAX  
    MIN  
    NORM  
  • Method Summary

    Modifier and Type Method Description
    int getTimeInMs()  
    static AckTimeout valueOf​(String name)
    Returns the enum constant of this type with the specified name.
    static AckTimeout[] values()
    Returns an array containing the constants of this enum type, in the order they are declared.

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait
  • Enum Constant Details

  • Method Details

    • values

      public static AckTimeout[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static AckTimeout valueOf​(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • getTimeInMs

      public int getTimeInMs()
      Specified by:
      getTimeInMs in interface org.refcodes.mixin.TimeInMsAccessor