Enum Class Annotator

java.lang.Object
java.lang.Enum<Annotator>
org.refcodes.data.Annotator
All Implemented Interfaces:
Serializable, Comparable<Annotator>, Constable, org.refcodes.mixin.CharAccessor

public enum Annotator extends Enum<Annotator> implements org.refcodes.mixin.CharAccessor
Commonly used characters to be prefixed to annotations' names to distinguish them form element names and the like.
  • Enum Constant Details

    • JAVA

      public static final Annotator JAVA
      The annotation prefix used by the Java language ('@').
  • Method Details

    • values

      public static Annotator[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static Annotator valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getChar

      public char getChar()
      Specified by:
      getChar in interface org.refcodes.mixin.CharAccessor