Enum Class Ascii

java.lang.Object
java.lang.Enum<Ascii>
org.refcodes.data.Ascii
All Implemented Interfaces:
Serializable, Comparable<Ascii>, Constable, org.refcodes.mixin.CharAccessor, org.refcodes.mixin.CodeAccessor<Byte>

public enum Ascii extends Enum<Ascii> implements org.refcodes.mixin.CodeAccessor<Byte>, org.refcodes.mixin.CharAccessor
Some ASCII codes used by REFCODES.ORG artifacts.
  • Nested Class Summary

    Nested classes/interfaces inherited from class java.lang.Enum

    Enum.EnumDesc<E extends Enum<E>>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.CharAccessor

    org.refcodes.mixin.CharAccessor.CharBuilder<B extends org.refcodes.mixin.CharAccessor.CharBuilder<B>>, org.refcodes.mixin.CharAccessor.CharMutator, org.refcodes.mixin.CharAccessor.CharProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.CodeAccessor

    org.refcodes.mixin.CodeAccessor.CodeBuilder<T,B extends org.refcodes.mixin.CodeAccessor.CodeBuilder<T,B>>, org.refcodes.mixin.CodeAccessor.CodeMutator<T>, org.refcodes.mixin.CodeAccessor.CodeProperty<T>
  • Enum Constant Summary

    Enum Constants
    Enum Constant
    Description
    ASCII(6) = <ACK>
    ASCII(7) = <BELL>
    ASCII(24) = <CAN>
    * ASCII(16) = <DLE>
    ASCII(25) = <EN>
    ASCII(5) = <ENQ>
    ASCII(4) = <EOT>
    ASCII(27) = <ESC>
    ASCII(3) = <ETX>
    ASCII(21) = <NAK>
    ASCII(0) = <NULL>
    ASCII(1) = <SOH>
    ASCII(2) = <STX>
    ASCII(22) = <SYN>
  • Method Summary

    Modifier and Type
    Method
    Description
    char
    static Ascii
    Returns the enum constant of this class with the specified name.
    static Ascii[]
    Returns an array containing the constants of this enum class, in the order they are declared.

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait
  • Enum Constant Details

    • NULL

      public static final Ascii NULL

      ASCII(0) = <NULL>

      "Null"

    • SOH

      public static final Ascii SOH

      ASCII(1) = <SOH>

      "Start of Heading"

    • STX

      public static final Ascii STX

      ASCII(2) = <STX>

      "Start of Text"

    • ETX

      public static final Ascii ETX

      ASCII(3) = <ETX>

      "End of Text"

    • EOT

      public static final Ascii EOT

      ASCII(4) = <EOT>

      "End of Transmission"

    • ENQ

      public static final Ascii ENQ

      ASCII(5) = <ENQ>

      "Enquiry"

    • ACK

      public static final Ascii ACK

      ASCII(6) = <ACK>

      "Acknowledgement"

    • BELL

      public static final Ascii BELL

      ASCII(7) = <BELL>

      "BEL"

    • DLE

      public static final Ascii DLE

      * ASCII(16) = <DLE>

      Data Link Escape

    • NAK

      public static final Ascii NAK

      ASCII(21) = <NAK>

      "Negative Acknowledgement"

    • SYN

      public static final Ascii SYN

      ASCII(22) = <SYN>

      "Synchronous Idle"

    • CAN

      public static final Ascii CAN

      ASCII(24) = <CAN>

      "Cancel"

    • EM

      public static final Ascii EM

      ASCII(25) = <EN>

      "End of Medium"

    • ESC

      public static final Ascii ESC

      ASCII(27) = <ESC>

      "Escape"

  • Method Details

    • values

      public static Ascii[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static Ascii valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getCode

      public Byte getCode()
      Specified by:
      getCode in interface org.refcodes.mixin.CodeAccessor<Byte>
    • getChar

      public char getChar()
      Specified by:
      getChar in interface org.refcodes.mixin.CharAccessor