- All Implemented Interfaces:
Serializable,Comparable<BooleanLiterals>,Constable
Some values's literal (
String) representation useful when parsing or
evaluating texts.-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionString[]getNames()An array of the names representing the set of folder names.static booleanReturns true in case the givenStringequals (ignoring the case) one of thefalseliterals as ofFALSEandgetNames().static booleanReturns true in case the givenStringequals (ignoring the case) one of thetrueliterals as ofTRUEandgetNames().static BooleanLiteralsReturns the enum constant of this class with the specified name.static BooleanLiterals[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
TRUE
Strings representing a "true" boolean value. -
FALSE
Strings representing a "false" boolean value.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getNames
An array of the names representing the set of folder names.- Returns:
- The array of folder names representing this set.
-
isTrue
Returns true in case the givenStringequals (ignoring the case) one of thetrueliterals as ofTRUEandgetNames().- Parameters:
aValue- The value to be tested whether it represents atrueliteral.- Returns:
- True in case we have a
trueliteral, else false.
-
isFalse
Returns true in case the givenStringequals (ignoring the case) one of thefalseliterals as ofFALSEandgetNames().- Parameters:
aValue- The value to be tested whether it represents afalseliteral.- Returns:
- True in case we have a
falseliteral, else false.
-