JavaScript is disabled on your browser.
Description
Nested Class Summary
Enum Constant Summary
Method Summary
Enum Constant Details
ALPHABETIC
ALPHANUMERIC
ARABIC_BASE64
ASCII
ASCII_SPECIAL
BASE64
BASE64URL
BINARY
CLOSING_BRACES
DECIMAL
ENCODED_AS_NUMBER
END_OF_LINE
END_OF_SENTENCE
ESCAPE_SEQUENCES
HEXADECIMAL
LINE_BREAK_MARKERS
LOWER_CASE
NUMERIC
OCTAL
OPENING_BRACES
QUOTES
REGEX_SPECIAL_CHARS
SPACE_MARKERS
UPPER_CASE
WHITE_SPACES
Method Details
values()
valueOf(String)
getCharSet()
hasChar(char)
toCharset(String)
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.CharSetAccessor
org.refcodes.mixin.CharSetAccessor.CharSetBuilder<B>, org.refcodes.mixin.CharSetAccessor.CharSetMutator, org.refcodes.mixin.CharSetAccessor.CharSetProperty
Enum Constant Summary
Enum Constants
Characters representing closing braces.
No prefixing zeros allowed when encoding a value as a number (e.g. int).
Declares the characters denoting an end of a sentence.
When formatting texts, those chars can be used to identify a possible
suitable end of line (when seeking for a position to do a line-break).
Characters representing opening braces.
When formatting texts, those chars can be used to identify a space
between two words.
Method Summary
All Methods Static Methods Instance Methods Concrete Methods
char[]
boolean
Returns the charset which's name matches the provided name, ignoring the
case and the underscore ("_").
Returns the enum constant of this class with the specified name.
Returns an array containing the constants of this enum class, in
the order they are declared.
Methods inherited from class Enum
clone , compareTo , describeConstable , equals , finalize , getDeclaringClass , hashCode , name , ordinal , toString , valueOf