- All Implemented Interfaces:
Serializable,Comparable<CommandArgPrefix>,java.lang.constant.Constable,org.refcodes.mixin.PrefixAccessor
public enum CommandArgPrefix extends Enum<CommandArgPrefix> implements org.refcodes.mixin.PrefixAccessor
Commonly used prefixes needful for analyzing, parsing or truncating command
line arguments and so on.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>>Nested classes/interfaces inherited from interface org.refcodes.mixin.PrefixAccessor
org.refcodes.mixin.PrefixAccessor.PrefixBuilder<B extends org.refcodes.mixin.PrefixAccessor.PrefixBuilder<B>>, org.refcodes.mixin.PrefixAccessor.PrefixMutator, org.refcodes.mixin.PrefixAccessor.PrefixProperty -
Enum Constant Summary
Enum Constants Enum Constant Description POSIX_LONG_OPTIONA command line argument (POSIX) long-option is prefixed with a double hyphen-minus "--".POSIX_SHORT_OPTIONA command line argument (POSIX) short-option is prefixed with a single hyphen-minus "-".WINDOWS_OPTIONA DOS box option is prefixed with a single slash "/". -
Method Summary
Modifier and Type Method Description StringgetPrefix()static String[]toPrefixes()Returns an array with allStringprefixes as ofgetPrefix()defined by this enumeration.static CommandArgPrefixvalueOf(String name)Returns the enum constant of this type with the specified name.static CommandArgPrefix[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
Enum Constant Details
-
WINDOWS_OPTION
A DOS box option is prefixed with a single slash "/". -
POSIX_SHORT_OPTION
A command line argument (POSIX) short-option is prefixed with a single hyphen-minus "-". -
POSIX_LONG_OPTION
A command line argument (POSIX) long-option is prefixed with a double hyphen-minus "--".
-
-
Method Details
-
values
Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getPrefix
- Specified by:
getPrefixin interfaceorg.refcodes.mixin.PrefixAccessor
-
toPrefixes
Returns an array with allStringprefixes as ofgetPrefix()defined by this enumeration.- Returns:
- The array with the according prefixes.
-