-
- All Known Subinterfaces:
DataLocator.DataLocatorProperty
public interface DataLocatorProvides an accessor for a data locator property (URLandInputStream).
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceDataLocator.DataLocatorBuilder<B extends DataLocator.DataLocatorBuilder<B>>Provides a builder for a data locator property.static interfaceDataLocator.DataLocatorMutatorProvides a mutator for a data locator property.static interfaceDataLocator.DataLocatorPropertyProvides a property (getter / setter) for a data locator property (width and height).
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description InputStreamgetDataInputStream()Gets the data input stream.URLgetDataUrl()Gets the data url.
-
-
-
Method Detail
-
getDataUrl
URL getDataUrl()
Gets the data url.- Returns:
- the data url
-
getDataInputStream
InputStream getDataInputStream()
Gets the data input stream.- Returns:
- the data input stream
-
-