Enum Delimiter

java.lang.Object
java.lang.Enum<Delimiter>
org.refcodes.data.Delimiter
All Implemented Interfaces:
Serializable, Comparable<Delimiter>, java.lang.constant.Constable, org.refcodes.mixin.CharAccessor

public enum Delimiter
extends Enum<Delimiter>
implements org.refcodes.mixin.CharAccessor
Commonly used characters when working with separated values or properties and the like making use of text separator characters .
  • Nested Class Summary

    Nested classes/interfaces inherited from class java.lang.Enum

    Enum.EnumDesc<E extends Enum<E>>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.CharAccessor

    org.refcodes.mixin.CharAccessor.CharBuilder<B extends org.refcodes.mixin.CharAccessor.CharBuilder<B>>, org.refcodes.mixin.CharAccessor.CharMutator, org.refcodes.mixin.CharAccessor.CharProperty
  • Enum Constant Summary

    Enum Constants
    Enum Constant Description
    ANSI_ESCAPE_PARAMETER
    The delimiter used to separate the parameters of an ANSI Escape-Sequence, e.g. the parameters "0", "1" and ""4" of the sequence "<ESC>[0;1;4m".
    ANSI_ESCAPE_PREFIX
    The delimiter used to separate the leading Escape-Code <ESC> of an ANSI Escape-Sequence from the succeeding portion, e.g. "[" separates <ESC> from "[0;1;4m" of the sequence "<ESC>[0;1;4m".
    ARRAY
    When concatenating the elements of an array to a single line, then per default this delimiter us used (":").
    CIPHER_UID
    The delimiter char separating a cipher UID from an encrypted text (":").
    COOKIE_PROPERTIES
    The delimiter separating properties (key/value-pairs/tuples) from each other (";").
    COOKIE_TUPEL
    The delimiter separating a cookie's tuple name from its value ("=").
    CORRELATION_ID
    The delimiter char separating correlation IDs from each other (":").
    CSV
    Default delimiter for CSV (comma separated values) lines; this is not necessarily a comma (","), moreover we choose to use the semicolon ";".
    DOS_PATH
    The path delimiter for all descendants of good old MS-DOS.
    HTTP_HEADER_ELEMENTS
    The delimiter in HTTP headers for multiple elements in a single header field, e.g. in the ACCEPT Header-Field separating multiple media type declarations from each other (",").
    INDEX
    A number (index) is prefixed by a hash ("#").
    INNER_CLASS
    The separator separating an inner class from a class in a fully qualified class name ("$").
    IP_V4
    IPv4 delimiter as of the CIDR notation (see "https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation").
    IP_V6
    IPv6 delimiter as of the CIDR notation (see "https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation").
    JAR_URL_RESOURCE
    Separates the JAR file from the therein addressed resource ("!").
    KEBAB_CASE
    When concatenating elements in a word written in kebab case (e.g.
    LIST
    When concatenating the elements of a list to a single line, then per default this delimiter us used (",").
    MEDIA_TYPE_PARAMETERS
    The delimiter separating a HTTP header's media type declaration from the (optional) parameters and the parameters from each other (";").
    METHOD_NAME
    The separator separating a method name from a class name ("#").
    NAMESPACE
    A hierarchy such as a package structure often is represented by dot "."
    PACKAGE_HIERARCHY
    The separator separating the packages from a package hierarchy (".").
    PATH
    The default path delimiter for all kinds of paths ("/"); the delimiter is used to compose address locators for resources from inside JAR files or for *nix alike operating systems.
    PROPERTY
    The delimiter separating a key from a value of a key/value property ("=").
    SNAKE_CASE
    When concatenating elements in a word written in snake case (e.g.
    SYSTEM_FILE_PATH
    The system's file path delimiter as used by the underlying operating system.
    URL_CREDENTIALS
    User-info representing a credentials in an URL are separated be a colon (":").
    URL_FRAGMENT
    A fragment is the hash ("#") separated suffix of an URL.
    URL_PORT
    When separating a host from a port in an URL, then per definition this delimiter is used (":").
    URL_QUERY
    The delimiter char separating the locator part from a query string of an URL ("?").
    URL_USER_INFO
    User-info (e.g. credentials) in an URL are separated be an ampersand ("@").
    WEB_FIELD
    The delimiter char separating one web field from another in a query string of an URL ("&").
  • Method Summary

    Modifier and Type Method Description
    char getChar()
    static Delimiter valueOf​(String name)
    Returns the enum constant of this type with the specified name.
    static Delimiter[] values()
    Returns an array containing the constants of this enum type, in the order they are declared.

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait
  • Enum Constant Details

    • ANSI_ESCAPE_PARAMETER

      public static final Delimiter ANSI_ESCAPE_PARAMETER
      The delimiter used to separate the parameters of an ANSI Escape-Sequence, e.g. the parameters "0", "1" and ""4" of the sequence "<ESC>[0;1;4m".
    • ANSI_ESCAPE_PREFIX

      public static final Delimiter ANSI_ESCAPE_PREFIX
      The delimiter used to separate the leading Escape-Code <ESC> of an ANSI Escape-Sequence from the succeeding portion, e.g. "[" separates <ESC> from "[0;1;4m" of the sequence "<ESC>[0;1;4m".
    • INDEX

      public static final Delimiter INDEX
      A number (index) is prefixed by a hash ("#").
    • URL_FRAGMENT

      public static final Delimiter URL_FRAGMENT
      A fragment is the hash ("#") separated suffix of an URL.
    • URL_CREDENTIALS

      public static final Delimiter URL_CREDENTIALS
      User-info representing a credentials in an URL are separated be a colon (":").
    • URL_USER_INFO

      public static final Delimiter URL_USER_INFO
      User-info (e.g. credentials) in an URL are separated be an ampersand ("@").
    • PATH

      public static final Delimiter PATH
      The default path delimiter for all kinds of paths ("/"); the delimiter is used to compose address locators for resources from inside JAR files or for *nix alike operating systems. To get the operating system's file separator use SystemProperty.FILE_SEPARATOR.
    • DOS_PATH

      public static final Delimiter DOS_PATH
      The path delimiter for all descendants of good old MS-DOS.
    • SYSTEM_FILE_PATH

      public static final Delimiter SYSTEM_FILE_PATH
      The system's file path delimiter as used by the underlying operating system.
    • CSV

      public static final Delimiter CSV
      Default delimiter for CSV (comma separated values) lines; this is not necessarily a comma (","), moreover we choose to use the semicolon ";".
    • ARRAY

      public static final Delimiter ARRAY
      When concatenating the elements of an array to a single line, then per default this delimiter us used (":").
    • IP_V4

      public static final Delimiter IP_V4
      IPv4 delimiter as of the CIDR notation (see "https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation").
    • IP_V6

      public static final Delimiter IP_V6
      IPv6 delimiter as of the CIDR notation (see "https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation").
    • URL_PORT

      public static final Delimiter URL_PORT
      When separating a host from a port in an URL, then per definition this delimiter is used (":").
    • LIST

      public static final Delimiter LIST
      When concatenating the elements of a list to a single line, then per default this delimiter us used (",").
    • SNAKE_CASE

      public static final Delimiter SNAKE_CASE
      When concatenating elements in a word written in snake case (e.g. "FIRST_LAST" for concatenating "first" with "last"), then this delimiter may be your choice ("_").
      See Also:
      "https://en.wikipedia.org/wiki/Snake_case"
    • KEBAB_CASE

      public static final Delimiter KEBAB_CASE
      When concatenating elements in a word written in kebab case (e.g. "FIRST-LAST" for concatenating "first" with "last"), then this delimiter may be your choice ("-").
      See Also:
      "https://en.wikipedia.org/wiki/Kebab_case"
    • NAMESPACE

      public static final Delimiter NAMESPACE
      A hierarchy such as a package structure often is represented by dot "." separated hierarchy "levels", e.g. "org.refcodes.data": The top level is "org", the next level is "refcodes", the fully qualified level representation would be "org.refcodes". The fully qualified level representation for the level "data" would be "org.refcodes.data". Got it? ;-)
    • PROPERTY

      public static final Delimiter PROPERTY
      The delimiter separating a key from a value of a key/value property ("=").
    • JAR_URL_RESOURCE

      public static final Delimiter JAR_URL_RESOURCE
      Separates the JAR file from the therein addressed resource ("!").
    • METHOD_NAME

      public static final Delimiter METHOD_NAME
      The separator separating a method name from a class name ("#").
    • INNER_CLASS

      public static final Delimiter INNER_CLASS
      The separator separating an inner class from a class in a fully qualified class name ("$").
    • PACKAGE_HIERARCHY

      public static final Delimiter PACKAGE_HIERARCHY
      The separator separating the packages from a package hierarchy (".").
    • CIPHER_UID

      public static final Delimiter CIPHER_UID
      The delimiter char separating a cipher UID from an encrypted text (":").
    • CORRELATION_ID

      public static final Delimiter CORRELATION_ID
      The delimiter char separating correlation IDs from each other (":").
    • WEB_FIELD

      public static final Delimiter WEB_FIELD
      The delimiter char separating one web field from another in a query string of an URL ("&").
    • URL_QUERY

      public static final Delimiter URL_QUERY
      The delimiter char separating the locator part from a query string of an URL ("?").
    • MEDIA_TYPE_PARAMETERS

      public static final Delimiter MEDIA_TYPE_PARAMETERS
      The delimiter separating a HTTP header's media type declaration from the (optional) parameters and the parameters from each other (";").
    • HTTP_HEADER_ELEMENTS

      public static final Delimiter HTTP_HEADER_ELEMENTS
      The delimiter in HTTP headers for multiple elements in a single header field, e.g. in the ACCEPT Header-Field separating multiple media type declarations from each other (",").
  • Method Details

    • values

      public static Delimiter[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static Delimiter valueOf​(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • getChar

      public char getChar()
      Specified by:
      getChar in interface org.refcodes.mixin.CharAccessor