Enum Class Delimiters
- All Implemented Interfaces:
Serializable,Comparable<Delimiters>,Constable
The
Delimiters groups Delimiter values belonging somehow
together or sharing a similar semantics.-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionchar[]getChars()Contains an array of the characters representing the delimiters in this grouping enumeration.booleanisDelimiter(char aDelimiter) Tests if the given delimiter is contained in theDelimitersdefinition.booleanisDelimiter(Delimiter aDelimiter) Tests if the given delimiter is contained in theDelimitersdefinition.static DelimitersReturns the enum constant of this class with the specified name.static Delimiters[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
PROPERTIES
-
PATHS
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
isDelimiter
public boolean isDelimiter(char aDelimiter) Tests if the given delimiter is contained in theDelimitersdefinition.- Parameters:
aDelimiter- the delimiter- Returns:
- True, if the given delimiter is contained in the
Delimitersdefinition, else false.
-
isDelimiter
Tests if the given delimiter is contained in theDelimitersdefinition.- Parameters:
aDelimiter- the delimiter- Returns:
- True, if the given delimiter is contained in the
Delimitersdefinition, else false.
-
getChars
public char[] getChars()Contains an array of the characters representing the delimiters in this grouping enumeration.- Returns:
- The character array of the herein contained delimiters.
-