Enum Class EndOfLine

java.lang.Object
java.lang.Enum<EndOfLine>
org.refcodes.data.EndOfLine
All Implemented Interfaces:
Serializable, Comparable<EndOfLine>, Constable, CharAccessor

public enum EndOfLine extends Enum<EndOfLine> implements CharAccessor
Commonly used characters for EOL markers in texts.
  • Enum Constant Details

    • CARRIAGE_RETURN

      public static final EndOfLine CARRIAGE_RETURN
    • LINE_FEED

      public static final EndOfLine LINE_FEED
  • Method Details

    • values

      public static EndOfLine[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static EndOfLine valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getChar

      public char getChar()
      Specified by:
      getChar in interface CharAccessor
    • isEndOfLine

      public static boolean isEndOfLine(char aEndOfLine)
      Tests if the given potential EOL character is contained in the EndOfLine enumeration.
      Parameters:
      aEndOfLine - the potential EOL character
      Returns:
      True, if the given EOL character is contained in the EndOfLine enumeration, else false.
    • toChars

      public static char[] toChars()
      Returns an array of the characters representing the EOL characters in this grouping enumeration.
      Returns:
      The character array of the herein contained EOL characters.