JavaScript is disabled on your browser.
Description
Nested Class Summary
Enum Constant Summary
Method Summary
Enum Constant Details
META_CREATED_DATE
META_MODIFIED_DATE
META_CREATED_BY
META_MOFIFIED_BY
META_TIMESTAMP
META_VERSION
LOG_LINE_NUMBER
LOG_DATE
LOG_PRIORITY
LOG_THREAD_NAME
LOG_MESSAGE
LOG_EXCEPTION
LOG_FULLY_QUALIFIED_CLASS_NAME
LOG_METHOD_NAME
LOG_CLASS_LINE_NUMBER
LOG_SESSION_ID
LOG_REQUEST_ID
Method Details
values()
valueOf(String)
getName()
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.NameAccessor
org.refcodes.mixin.NameAccessor.NameBuilder<B extends org.refcodes.mixin.NameAccessor.NameBuilder<B>>, org.refcodes.mixin.NameAccessor.NameMutator, org.refcodes.mixin.NameAccessor.NameProperty
Enum Constant Summary
Enum Constants
Method Summary
All Methods Static Methods Instance Methods Concrete Methods
Returns the enum constant of this class with the specified name.
Returns an array containing the constants of this enum class, in
the order they are declared.
Methods inherited from class java.lang.Enum
clone , compareTo , describeConstable , equals , finalize , getDeclaringClass , hashCode , name , ordinal , toString , valueOf
Enum Constant Details
LOG_FULLY_QUALIFIED_CLASS_NAME