Enum FilenameExtension

java.lang.Object
java.lang.Enum<FilenameExtension>
org.refcodes.data.FilenameExtension
All Implemented Interfaces:
Serializable, Comparable<FilenameExtension>, java.lang.constant.Constable, org.refcodes.mixin.FilenameExtensionAccessor

public enum FilenameExtension
extends Enum<FilenameExtension>
implements org.refcodes.mixin.FilenameExtensionAccessor
The FilenameExtension define values useful when working with files or a file-system.
  • Enum Constant Details

  • Method Details

    • values

      public static FilenameExtension[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static FilenameExtension valueOf​(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • getFilenameExtension

      public String getFilenameExtension()
      Gets the extension.
      Specified by:
      getFilenameExtension in interface org.refcodes.mixin.FilenameExtensionAccessor
      Returns:
      the extension