Enum Literals

java.lang.Object
java.lang.Enum<Literals>
org.refcodes.data.Literals
All Implemented Interfaces:
Serializable, Comparable<Literals>, java.lang.constant.Constable

public enum Literals
extends Enum<Literals>
Some values's literal (String) representation useful when parsing or evaluating texts.
  • Enum Constant Details

    • TRUE

      public static final Literals TRUE
      Strings representing a "true" boolean value.
    • FALSE

      public static final Literals FALSE
      Strings representing a "false" boolean value.
  • Method Details

    • values

      public static Literals[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static Literals valueOf​(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • getNames

      public String[] getNames()
      An array of the names representing the set of folder names.
      Returns:
      The array of folder names representing this set.