Enum Class LoopExtensionTime

java.lang.Object
java.lang.Enum<LoopExtensionTime>
org.refcodes.data.LoopExtensionTime
All Implemented Interfaces:
Serializable, Comparable<LoopExtensionTime>, Constable, TimeMillisAccessor

public enum LoopExtensionTime extends Enum<LoopExtensionTime> implements TimeMillisAccessor
The LoopExtensionTime defined values used inside a control flow.
  • Enum Constant Details

    • MIN

      public static final LoopExtensionTime MIN
      A retry is being extended for each retry by an exponential delay extension time (when > 0): long theDelay((long) ( Math.pow(4, theRetries++ ) * EXTENSION_TIME ))), Also see http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdf
    • NORM

      public static final LoopExtensionTime NORM
      A retry is being extended for each retry by an exponential delay extension time (when > 0): long theDelay((long) ( Math.pow(4, theRetries++ ) * EXTENSION_TIME ))), Also see http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdf
    • MAX

      public static final LoopExtensionTime MAX
      A retry is being extended for each retry by an exponential delay extension time (when > 0): long theDelay((long) ( Math.pow(4, theRetries++ ) * EXTENSION_TIME ))), See also http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdf
  • Method Details

    • values

      public static LoopExtensionTime[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static LoopExtensionTime valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getTimeMillis

      public int getTimeMillis()
      Specified by:
      getTimeMillis in interface TimeMillisAccessor