All Implemented Interfaces:
Serializable , Comparable <MarshalParameter >, java.lang.constant.Constable, org.refcodes.mixin.NameAccessor
public enum MarshalParameter
extends Enum <MarshalParameter >
implements org.refcodes.mixin.NameAccessor
MarshalParameter defines common parameters (parameter is considered
the key of a key/value pair) of a given semantics for the according property.
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.NameAccessor
org.refcodes.mixin.NameAccessor.NameBuilder<B extends org.refcodes.mixin.NameAccessor.NameBuilder<B>>, org.refcodes.mixin.NameAccessor.NameMutator, org.refcodes.mixin.NameAccessor.NameProperty
Enum Constant Summary
Enum Constants
Enum Constant
Description
BASE_URL
A base URL may be stored in such a property.
CHARSET
COMMENT
DELIMITER
The value of such a property identifies a single delimiter char.
DELIMITERS
The value of such a property identifies a multiple delimiter chars.
ENCODING
HEADER
E.g. used in an XML file's head's declaration such as
<?
ROOT_ELEMENT
The root element to be used when marshaling a structure to a notation
which requires a root element.
STAND_ALONE
E.g. used in an XML file's head's declaration such as
<?
VERSION
Identifies a version, such as an XML version (depends on the notation to
which to marshal).
Method Summary
All Methods Static Methods Instance Methods Concrete Methods
Methods inherited from class java.lang.Enum
clone , compareTo , describeConstable , equals , finalize , getDeclaringClass , hashCode , name , ordinal , toString , valueOf
Enum Constant Details
BASE_URL
A base URL may be stored in such a property.
DELIMITER
The value of such a property identifies a single delimiter char.
DELIMITERS
The value of such a property identifies a multiple delimiter chars.
VERSION
Identifies a version, such as an XML version (depends on the notation to
which to marshal).
ROOT_ELEMENT
The root element to be used when marshaling a structure to a notation
which requires a root element.
STAND_ALONE
E.g. used in an XML file's head's declaration such as
<?xml ecnoding="UTF-8" version="1.0" standalone="yes"?>
to determine whether this is a stand alone document (note that it is
declared as "standalone"!).
Method Details
values
Returns an array containing the constants of this enum type, in
the order they are declared.
Returns:
an array containing the constants of this enum type, in the order they are declared
valueOf
Returns the enum constant of this type with the specified name.
The string must match exactly an identifier used to declare an
enum constant in this type. (Extraneous whitespace characters are
not permitted.)
Parameters:
name - the name of the enum constant to be returned.
Returns:
the enum constant with the specified name
Throws:
IllegalArgumentException - if this enum type has no constant with the specified name
NullPointerException - if the argument is null
getName
Specified by:
getName in interface org.refcodes.mixin.NameAccessor