JavaScript is disabled on your browser.
Description
Nested Class Summary
Enum Constant Summary
Method Summary
Enum Constant Details
FTP
SSH
TELNET
SMTP
DNS
HTTP
POP3
NNTP
NTP
IMAP
SNMP
IRC
HTTPS
REFCODES
HTTP_ALTERNATE
Method Details
values()
valueOf(String)
getPort()
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.PortAccessor
org.refcodes.mixin.PortAccessor.PortBuilder<B>, org.refcodes.mixin.PortAccessor.PortMutator, org.refcodes.mixin.PortAccessor.PortProperty
Enum Constant Summary
Enum Constants
Domain Name System (DNS) service:.
File Transfer Protocol (FTP):.
Hypertext Transfer Protocol (HTTP) used in the World Wide Web:.
HTTP alternate (http_alt).
Internet Message Access Protocol (IMAP):.
Internet Relay Chat (IRC):.
Network News Transfer Protocol (NNTP):.
Network Time Protocol (NTP):.
Post Office Protocol (POP3):.
Simple Mail Transfer Protocol (SMTP):.
Simple Network Management Protocol (SNMP):.
Telnet remote login service:.
Method Summary
All Methods Static Methods Instance Methods Concrete Methods
int
Returns the enum constant of this class with the specified name.
Returns an array containing the constants of this enum class, in
the order they are declared.
Methods inherited from class Enum
clone , compareTo , describeConstable , equals , finalize , getDeclaringClass , hashCode , name , ordinal , toString , valueOf