Record Class Region

java.lang.Object
java.lang.Record
org.refcodes.data.Region

public record Region(int beginIndex, int endIndex) extends Record
A text region has a beginning index being included by the region and an end index being excluded by the region and a resulting length.
  • Constructor Summary

    Constructors
    Constructor
    Description
    Region(int beginIndex, int endIndex)
    Creates an instance of a Region record class.
  • Method Summary

    Modifier and Type
    Method
    Description
    int
    Returns the value of the beginIndex record component.
    int
    Returns the value of the endIndex record component.
    final boolean
    Indicates whether some other object is "equal to" this one.
    final int
    Returns a hash code value for this object.
    int
    Returns the length of the region as of (endIndex() - beginIndex()).
    final String
    Returns a string representation of this record class.

    Methods inherited from class java.lang.Object

    clone, finalize, getClass, notify, notifyAll, wait, wait, wait
  • Constructor Details

    • Region

      public Region(int beginIndex, int endIndex)
      Creates an instance of a Region record class.
      Parameters:
      beginIndex - the value for the beginIndex record component
      endIndex - the value for the endIndex record component
  • Method Details

    • toLength

      public int toLength()
      Returns the length of the region as of (endIndex() - beginIndex()).
      Returns:
      The length of the region.
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with the compare method from their corresponding wrapper classes.
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • beginIndex

      public int beginIndex()
      Returns the value of the beginIndex record component.
      Returns:
      the value of the beginIndex record component
    • endIndex

      public int endIndex()
      Returns the value of the endIndex record component.
      Returns:
      the value of the endIndex record component