Enum Class Scheme

java.lang.Object
java.lang.Enum<Scheme>
org.refcodes.data.Scheme
All Implemented Interfaces:
Serializable, Comparable<Scheme>, Constable, org.refcodes.mixin.NameAccessor, org.refcodes.mixin.PortAccessor

public enum Scheme extends Enum<Scheme> implements org.refcodes.mixin.NameAccessor, org.refcodes.mixin.PortAccessor
The Scheme define values useful when working with files or a file-system. An URL-Scheme is constructed as follows: "name:scheme-specific-part" The name is the protocol of the scheme such as "file" or "http". The scheme specific part is the part after the colon (":") specific to the given scheme. For a "file" scheme it would be just an empty String where as for "http" it would be "//" (as of "http://", "http" being the name).