Enum Class Suffix

java.lang.Object
java.lang.Enum<Suffix>
org.refcodes.data.Suffix
All Implemented Interfaces:
Serializable, Comparable<Suffix>, Constable, SuffixAccessor

public enum Suffix extends Enum<Suffix> implements SuffixAccessor
Commonly used characters needful for analyzing, parsing or truncating texts.
  • Enum Constant Details

    • PROTOCOL

      public static final Suffix PROTOCOL
  • Method Details

    • values

      public static Suffix[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static Suffix valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getSuffix

      public String getSuffix()
      Specified by:
      getSuffix in interface SuffixAccessor