Enum SystemProperty

java.lang.Object
java.lang.Enum<SystemProperty>
org.refcodes.data.SystemProperty
All Implemented Interfaces:
Serializable, Comparable<SystemProperty>, java.lang.constant.Constable, org.refcodes.mixin.KeyAccessor<String>, org.refcodes.mixin.ValueAccessor<String>, org.refcodes.mixin.ValueAccessor.ValueMutator<String>, org.refcodes.mixin.ValueAccessor.ValueProperty<String>

public enum SystemProperty
extends Enum<SystemProperty>
implements org.refcodes.mixin.KeyAccessor<String>, org.refcodes.mixin.ValueAccessor.ValueProperty<String>
SystemProperty define values to be used at runtime. Them are passed to a JVM by prefixing a "-D" to the actual "property=value" pair.
  • Nested Class Summary

    Nested classes/interfaces inherited from class java.lang.Enum

    Enum.EnumDesc<E extends Enum<E>>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor

    org.refcodes.mixin.KeyAccessor.KeyBuilder<K extends Object,​B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K,​B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K extends Object>, org.refcodes.mixin.KeyAccessor.KeyProperty<K extends Object>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor

    org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,​B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,​B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>
  • Enum Constant Summary

    Enum Constants
    Enum Constant Description
    CONFIG_DIR
    Pass as JVM argument via "-Dconfig.dir=path_to_your_config_dir" (where path_to_your_config_dir stands for the path to the directory where you placed configuration files such as the "runtimelogger.ini" file).
    CONSOLE_ANSI
    Pass as JVM argument via -Dconsole.ansi=<true|false> where "true" or "false" forces ANSI to be used / not used by REFCODES.ORG artifacts, no matter what capabilities were detected for the hosting terminal.
    CONSOLE_HEIGHT
    Pass as JVM argument via "-Dconsole.height=n" (where n stands for the number of lines).
    CONSOLE_LINE_BREAK
    The console's line-break property.
    CONSOLE_WIDTH
    Pass as JVM argument via "-Dconsole.width=n" (where n stands for the number of chars per row).
    FILE_SEPARATOR
    The OS specific file separator is retrieved by this system property.
    HOST_SEED
    System property "host.seed" for the Host-Seed for host-related IDs.
    HTTP_NON_PROXY_HOSTS
    No-Proxy settings for the HTTP_PROXY_HOST (HTTP_PROXY_PORT) settings in a comma separated list ("localhost,127.0.0.0/8,127.0.1.1,127.0.1.1*,...")
    HTTP_PROXY_HOST
    HTTP-Proxy host without a port ("http://my.company.org")
    HTTP_PROXY_PORT
    HTTP-Proxy port ("3128")
    HTTPS_NON_PROXY_HOSTS
    No-Proxy settings for the HTTPS_PROXY_HOST (HTTPS_PROXY_PORT) settings in a comma separated list ("localhost,127.0.0.0/8,127.0.1.1,127.0.1.1*,...")
    HTTPS_PROXY_HOST
    HTTPS-Proxy host without a port ("http://my.company.org")
    HTTPS_PROXY_PORT
    HTTP-Proxy port ("3128")
    JAVA_AWT_HEADLESS
    To set up headless mode, set the appropriate system property ("https://www.oracle.com/technetwork/articles/javase/headless-136834.html").
    KEY_STORE_FILE
    Location of the Java keystore file containing an application process's own certificate and private key.
    KEY_STORE_PASSWORD
    Password to access the private key from the keystore file specified by KEY_STORE_FILE.
    KEY_STORE_TYPE
    For Java keystore file format, this property has the value "jks" (or "JKS").
    LAUNCHER_DIR
    Specifies the path to your application's launcher dir, e.g. the place where your JAR resides in.
    LINE_SEPARATOR
    Sequence used by operating system to separate lines in text files.
    LOGGER_LAYOUT
    Pass as JVM argument via "-Dlogger.layout=<layout>" (where <layout> stands for the chosen layout for the REFCODES.ORG logger artifacts.).
    LOGGER_STYLE
    Pass as JVM argument via "-Dlogger.style=<style>" (where <style> stands for the chosen logger-style for the REFCODES.ORG logger artifacts.).
    OPERATING_SYSTEM_NAME
    Operating system name.
    OS_ARCH
    Processor architecture on some systems (e.g.
    PROCESS_ID
    At least set on Ubuntu-Linux:.
    SOCKS_PROXY_HOST
    SOCKS-Proxy host without a port ("http://my.company.org")
    SOCKS_PROXY_PORT
    SOCKS-Proxy port ("3128")
    TEMP_DIR
    The OS specific temp folder path.
    TRUST_STORE_FILE
    Location of the Java keystore file containing the collection of CA certificates trusted by this application process (trust store).
    TRUST_STORE_PASSWORD
    Password to unlock the keystore file (store password) specified by TRUST_STORE_FILE.
    TRUST_STORE_TYPE
    For Java keystore file format, this property has the value "jks" (or "JKS").
    USER_DIR
    System variable holding the user's current working directory.
    USER_HOME
    System variable holding the user's home folder path.
    USER_NAME
    System variable holding the user's login name.
  • Method Summary

    Modifier and Type Method Description
    String getKey()
    String getValue()
    void setValue​(String aValue)
    static SystemProperty valueOf​(String name)
    Returns the enum constant of this type with the specified name.
    static SystemProperty[] values()
    Returns an array containing the constants of this enum type, in the order they are declared.

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait

    Methods inherited from interface org.refcodes.mixin.ValueAccessor

    getValueOr

    Methods inherited from interface org.refcodes.mixin.ValueAccessor.ValueProperty

    letValue
  • Enum Constant Details

    • JAVA_AWT_HEADLESS

      public static final SystemProperty JAVA_AWT_HEADLESS
      To set up headless mode, set the appropriate system property ("https://www.oracle.com/technetwork/articles/javase/headless-136834.html").
    • HTTP_PROXY_HOST

      public static final SystemProperty HTTP_PROXY_HOST
      HTTP-Proxy host without a port ("http://my.company.org")
    • HTTP_PROXY_PORT

      public static final SystemProperty HTTP_PROXY_PORT
      HTTP-Proxy port ("3128")
    • HTTPS_PROXY_HOST

      public static final SystemProperty HTTPS_PROXY_HOST
      HTTPS-Proxy host without a port ("http://my.company.org")
    • HTTPS_PROXY_PORT

      public static final SystemProperty HTTPS_PROXY_PORT
      HTTP-Proxy port ("3128")
    • SOCKS_PROXY_HOST

      public static final SystemProperty SOCKS_PROXY_HOST
      SOCKS-Proxy host without a port ("http://my.company.org")
    • SOCKS_PROXY_PORT

      public static final SystemProperty SOCKS_PROXY_PORT
      SOCKS-Proxy port ("3128")
    • HOST_SEED

      public static final SystemProperty HOST_SEED
      System property "host.seed" for the Host-Seed for host-related IDs.
    • HTTP_NON_PROXY_HOSTS

      public static final SystemProperty HTTP_NON_PROXY_HOSTS
      No-Proxy settings for the HTTP_PROXY_HOST (HTTP_PROXY_PORT) settings in a comma separated list ("localhost,127.0.0.0/8,127.0.1.1,127.0.1.1*,...")
    • HTTPS_NON_PROXY_HOSTS

      public static final SystemProperty HTTPS_NON_PROXY_HOSTS
      No-Proxy settings for the HTTPS_PROXY_HOST (HTTPS_PROXY_PORT) settings in a comma separated list ("localhost,127.0.0.0/8,127.0.1.1,127.0.1.1*,...")
    • OS_ARCH

      public static final SystemProperty OS_ARCH
      Processor architecture on some systems (e.g. "AMD64").
    • CONFIG_DIR

      public static final SystemProperty CONFIG_DIR
      Pass as JVM argument via "-Dconfig.dir=path_to_your_config_dir" (where path_to_your_config_dir stands for the path to the directory where you placed configuration files such as the "runtimelogger.ini" file).
    • FILE_SEPARATOR

      public static final SystemProperty FILE_SEPARATOR
      The OS specific file separator is retrieved by this system property. ATTENTION: System properties are to be retrieved via System.getProperty(String).
    • TEMP_DIR

      public static final SystemProperty TEMP_DIR
      The OS specific temp folder path.
    • PROCESS_ID

      public static final SystemProperty PROCESS_ID
      At least set on Ubuntu-Linux:.
    • LINE_SEPARATOR

      public static final SystemProperty LINE_SEPARATOR
      Sequence used by operating system to separate lines in text files.
    • OPERATING_SYSTEM_NAME

      public static final SystemProperty OPERATING_SYSTEM_NAME
      Operating system name.
    • LAUNCHER_DIR

      public static final SystemProperty LAUNCHER_DIR
      Specifies the path to your application's launcher dir, e.g. the place where your JAR resides in. Pass as JVM argument via "-Dlauncher.dir=/path/to/launcher/dir".
    • CONSOLE_HEIGHT

      public static final SystemProperty CONSOLE_HEIGHT
      Pass as JVM argument via "-Dconsole.height=n" (where n stands for the number of lines).
    • CONSOLE_WIDTH

      public static final SystemProperty CONSOLE_WIDTH
      Pass as JVM argument via "-Dconsole.width=n" (where n stands for the number of chars per row).
    • CONSOLE_ANSI

      public static final SystemProperty CONSOLE_ANSI
      Pass as JVM argument via -Dconsole.ansi=<true|false> where "true" or "false" forces ANSI to be used / not used by REFCODES.ORG artifacts, no matter what capabilities were detected for the hosting terminal.
    • CONSOLE_LINE_BREAK

      public static final SystemProperty CONSOLE_LINE_BREAK
      The console's line-break property. Used to override any default line breaks for the REFCODES-ORG artifacts.
    • LOGGER_LAYOUT

      public static final SystemProperty LOGGER_LAYOUT
      Pass as JVM argument via "-Dlogger.layout=<layout>" (where <layout> stands for the chosen layout for the REFCODES.ORG logger artifacts.).
    • LOGGER_STYLE

      public static final SystemProperty LOGGER_STYLE
      Pass as JVM argument via "-Dlogger.style=<style>" (where <style> stands for the chosen logger-style for the REFCODES.ORG logger artifacts.).
    • USER_HOME

      public static final SystemProperty USER_HOME
      System variable holding the user's home folder path.
    • USER_NAME

      public static final SystemProperty USER_NAME
      System variable holding the user's login name.
    • USER_DIR

      public static final SystemProperty USER_DIR
      System variable holding the user's current working directory.
    • KEY_STORE_FILE

      public static final SystemProperty KEY_STORE_FILE
      Location of the Java keystore file containing an application process's own certificate and private key.
    • KEY_STORE_PASSWORD

      public static final SystemProperty KEY_STORE_PASSWORD
      Password to access the private key from the keystore file specified by KEY_STORE_FILE.
    • KEY_STORE_TYPE

      public static final SystemProperty KEY_STORE_TYPE
      For Java keystore file format, this property has the value "jks" (or "JKS"). Its default value is already "jks".
    • TRUST_STORE_FILE

      public static final SystemProperty TRUST_STORE_FILE
      Location of the Java keystore file containing the collection of CA certificates trusted by this application process (trust store).
    • TRUST_STORE_PASSWORD

      public static final SystemProperty TRUST_STORE_PASSWORD
      Password to unlock the keystore file (store password) specified by TRUST_STORE_FILE.
    • TRUST_STORE_TYPE

      public static final SystemProperty TRUST_STORE_TYPE
      For Java keystore file format, this property has the value "jks" (or "JKS"). Its default value is already "jks".
  • Method Details

    • values

      public static SystemProperty[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static SystemProperty valueOf​(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • getKey

      public String getKey()
      Specified by:
      getKey in interface org.refcodes.mixin.KeyAccessor<String>
    • getValue

      public String getValue()
      Specified by:
      getValue in interface org.refcodes.mixin.ValueAccessor<String>
    • setValue

      public void setValue​(String aValue)
      Specified by:
      setValue in interface org.refcodes.mixin.ValueAccessor.ValueMutator<String>