Enum Class Wildcard
- All Implemented Interfaces:
Serializable, Comparable<Wildcard>, Constable, ValueAccessor<String>
Commonly used characters needful for analyzing, parsing or truncating texts.
-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E>Nested classes/interfaces inherited from interface ValueAccessor
ValueAccessor.ValueBuilder<V,B>, ValueAccessor.ValueMutator<V>, ValueAccessor.ValueProperty<V> -
Enum Constant Summary
Enum Constants -
Method Summary
Methods inherited from class Enum
clone, compareTo, describeConstable, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOfMethods inherited from interface ValueAccessor
getValueOr, hasValue
-
Enum Constant Details
-
CHAR
-
FILE
-
PATH
-
QUERY
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
- Specified by:
getValuein interfaceValueAccessor<String>
-