Uses of Enum Class
org.refcodes.data.Alignment
-
Uses of Alignment in org.refcodes.data
Subclasses with type arguments of type Alignment in org.refcodes.dataModifier and TypeClassDescriptionenumDefines enumeration elements for the left and the right side.Methods in org.refcodes.data that return Alignment