Uses of Enum Class
org.refcodes.data.Annotator
-
Uses of Annotator in org.refcodes.data
Subclasses with type arguments of type Annotator in org.refcodes.dataModifier and TypeClassDescriptionenumCommonly used characters to be prefixed to annotations' names to distinguish them form element names and the like.Methods in org.refcodes.data that return Annotator