Uses of Enum Class
org.refcodes.data.ArgsPrefix
-
Uses of ArgsPrefix in org.refcodes.data
Subclasses with type arguments of type ArgsPrefix in org.refcodes.dataModifier and TypeClassDescriptionenumCommonly used prefixes needful for analyzing, parsing or truncating command line arguments and so on.Methods in org.refcodes.data that return ArgsPrefixModifier and TypeMethodDescriptionArgsPrefixes.getCommandArgPrefixes()Returns the relatedArgsPrefixelements.static ArgsPrefixReturns the enum constant of this class with the specified name.static ArgsPrefix[]ArgsPrefix.values()Returns an array containing the constants of this enum class, in the order they are declared.