Uses of Enum Class
org.refcodes.data.Ascii

  • Uses of Ascii in org.refcodes.data

    Subclasses with type arguments of type Ascii in org.refcodes.data
    Modifier and Type
    Class
    Description
    enum 
    Some ASCII codes used by REFCODES.ORG artifacts.
    Methods in org.refcodes.data that return Ascii
    Modifier and Type
    Method
    Description
    static Ascii
    Ascii.valueOf(String name)
    Returns the enum constant of this class with the specified name.
    static Ascii[]
    Ascii.values()
    Returns an array containing the constants of this enum class, in the order they are declared.