JavaScript is disabled on your browser.
Skip navigation links
Module
Class
Use
Tree
Index
Search
Help
org.refcodes.data
org.refcodes.data
Binary
Uses of Enum Class
org.refcodes.data.Binary
Uses of
Binary
in
org.refcodes.data
Subclasses with type arguments of type
Binary
in
org.refcodes.data
Modifier and Type
Class
Description
enum
Binary
Some values regarding binary numbers.
Methods in
org.refcodes.data
that return
Binary
Modifier and Type
Method
Description
static
Binary
Binary.
valueOf
(
String
name)
Returns the enum constant of this class with the specified name.
static
Binary
[]
Binary.
values
()
Returns an array containing the constants of this enum class, in the order they are declared.