JavaScript is disabled on your browser.
Skip navigation links
Module
Class
Use
Tree
Index
Search
Help
org.refcodes.data
org.refcodes.data
BitMask
Uses of Enum Class
org.refcodes.data.BitMask
Uses of
BitMask
in
org.refcodes.data
Subclasses with type arguments of type
BitMask
in
org.refcodes.data
Modifier and Type
Class
Description
enum
BitMask
The Enum BitMask.
Methods in
org.refcodes.data
that return
BitMask
Modifier and Type
Method
Description
static
BitMask
BitMask.
valueOf
(
String
name)
Returns the enum constant of this class with the specified name.
static
BitMask
[]
BitMask.
values
()
Returns an array containing the constants of this enum class, in the order they are declared.