Uses of Enum Class
org.refcodes.data.CommandArgPrefix
-
Uses of CommandArgPrefix in org.refcodes.data
Methods in org.refcodes.data that return CommandArgPrefixModifier and TypeMethodDescriptionCommandArgPrefixes.getCommandArgPrefixes()Returns the relatedCommandArgPrefixelements.static CommandArgPrefixReturns the enum constant of this class with the specified name.static CommandArgPrefix[]CommandArgPrefix.values()Returns an array containing the constants of this enum class, in the order they are declared.