Uses of Enum Class
org.refcodes.data.CommandArgPrefixes
-
Uses of CommandArgPrefixes in org.refcodes.data
Methods in org.refcodes.data that return CommandArgPrefixesModifier and TypeMethodDescriptionstatic CommandArgPrefixesReturns the enum constant of this class with the specified name.static CommandArgPrefixes[]CommandArgPrefixes.values()Returns an array containing the constants of this enum class, in the order they are declared.