Uses of Enum Class
org.refcodes.data.DaemonLoopSleepTime
-
Uses of DaemonLoopSleepTime in org.refcodes.data
Methods in org.refcodes.data that return DaemonLoopSleepTimeModifier and TypeMethodDescriptionstatic DaemonLoopSleepTimeReturns the enum constant of this class with the specified name.static DaemonLoopSleepTime[]DaemonLoopSleepTime.values()Returns an array containing the constants of this enum class, in the order they are declared.