Uses of Enum Class
org.refcodes.data.Delimiters
-
Uses of Delimiters in org.refcodes.data
Subclasses with type arguments of type Delimiters in org.refcodes.dataModifier and TypeClassDescriptionenumTheDelimitersgroupsDelimitervalues belonging somehow together or sharing a similar semantics.Methods in org.refcodes.data that return DelimitersModifier and TypeMethodDescriptionstatic DelimitersReturns the enum constant of this class with the specified name.static Delimiters[]Delimiters.values()Returns an array containing the constants of this enum class, in the order they are declared.