Uses of Enum Class
org.refcodes.data.Encoding
-
Uses of Encoding in org.refcodes.data
Subclasses with type arguments of type Encoding in org.refcodes.dataModifier and TypeClassDescriptionenumTheEncodingdefine values representing an encoding which are to be passed as argument to according methods.Methods in org.refcodes.data that return Encoding