Uses of Enum Class
org.refcodes.data.EnvironmentVariable
-
Uses of EnvironmentVariable in org.refcodes.data
Methods in org.refcodes.data that return EnvironmentVariableModifier and TypeMethodDescriptionstatic EnvironmentVariableReturns the enum constant of this class with the specified name.static EnvironmentVariable[]EnvironmentVariable.values()Returns an array containing the constants of this enum class, in the order they are declared.