Uses of Enum Class
org.refcodes.data.EscapeCode
-
Uses of EscapeCode in org.refcodes.data
Methods in org.refcodes.data that return EscapeCodeModifier and TypeMethodDescriptionstatic EscapeCodeEscapeCode.toEscapeCode(char aEscapeCode) Translate the providedEscapeCodecharacter to the according escape sequence.static EscapeCodeEscapeCode.toEscapeCode(String aEscapeSequence) Translate the provided escape sequence to the accordingEscapeCodeelement.static EscapeCodeReturns the enum constant of this class with the specified name.static EscapeCode[]EscapeCode.values()Returns an array containing the constants of this enum class, in the order they are declared.