Uses of Enum Class
org.refcodes.data.Field

  • Uses of Field in org.refcodes.data

    Subclasses with type arguments of type Field in org.refcodes.data
    Modifier and Type
    Class
    Description
    enum 
    The Field are useful when working with fields defined for external systems such as databases or when working with tables or Map instances.
    Methods in org.refcodes.data that return Field
    Modifier and Type
    Method
    Description
    static Field
    Field.valueOf(String name)
    Returns the enum constant of this class with the specified name.
    static Field[]
    Field.values()
    Returns an array containing the constants of this enum class, in the order they are declared.