Uses of Enum Class
org.refcodes.data.FilenameExtension
-
Uses of FilenameExtension in org.refcodes.data
Subclasses with type arguments of type FilenameExtension in org.refcodes.dataModifier and TypeClassDescriptionenumTheFilenameExtensiondefine values useful when working with files or a file-system.Methods in org.refcodes.data that return FilenameExtensionModifier and TypeMethodDescriptionstatic FilenameExtensionFilenameExtension.toFileNameExtension(String aFilename) Determines the filename'sFilenameExtensiondefinition.static FilenameExtensionReturns the enum constant of this class with the specified name.static FilenameExtension[]FilenameExtension.values()Returns an array containing the constants of this enum class, in the order they are declared.