Uses of Enum Class
org.refcodes.data.Flag

  • Uses of Flag in org.refcodes.data

    Subclasses with type arguments of type Flag in org.refcodes.data
    Modifier and Type
    Class
    Description
    enum 
    A flag can be on or off.
    Methods in org.refcodes.data that return Flag
    Modifier and Type
    Method
    Description
    static Flag
    Flag.valueOf(String name)
    Returns the enum constant of this class with the specified name.
    static Flag[]
    Flag.values()
    Returns an array containing the constants of this enum class, in the order they are declared.