JavaScript is disabled on your browser.
Skip navigation links
Module
Package
Class
Use
Tree
Index
Help
SEARCH
Uses of Enum Class
org.refcodes.data.Folder
Uses of
Folder
in
org.refcodes.data
Methods in
org.refcodes.data
that return
Folder
Modifier and Type
Method
Description
static
Folder
Folder.
valueOf
(
String
name)
Returns the enum constant of this class with the specified name.
static
Folder
[]
Folder.
values
()
Returns an array containing the constants of this enum class, in the order they are declared.