Uses of Enum Class
org.refcodes.data.Folders
-
Uses of Folders in org.refcodes.data
Subclasses with type arguments of type Folders in org.refcodes.dataModifier and TypeClassDescriptionenumTheFoldersdefine values useful when working with folders on a file-system.Methods in org.refcodes.data that return Folders