Uses of Enum Class
org.refcodes.data.IoHeurisitcsTimeToLive
-
Uses of IoHeurisitcsTimeToLive in org.refcodes.data
Subclasses with type arguments of type IoHeurisitcsTimeToLive in org.refcodes.dataModifier and TypeClassDescriptionenumTheIoHeurisitcsTimeToLivedefines values used to cache IO related heuristics (e.g. meta data of or for remote systems)Methods in org.refcodes.data that return IoHeurisitcsTimeToLiveModifier and TypeMethodDescriptionstatic IoHeurisitcsTimeToLiveReturns the enum constant of this class with the specified name.static IoHeurisitcsTimeToLive[]IoHeurisitcsTimeToLive.values()Returns an array containing the constants of this enum class, in the order they are declared.