Uses of Enum Class
org.refcodes.data.IoPollLoopTime
-
Uses of IoPollLoopTime in org.refcodes.data
Subclasses with type arguments of type IoPollLoopTime in org.refcodes.dataModifier and TypeClassDescriptionenumTheIoPollLoopTimedefined values used when polling data from I/O, e.g. the file system or via TCP/IP.Methods in org.refcodes.data that return IoPollLoopTimeModifier and TypeMethodDescriptionstatic IoPollLoopTimeReturns the enum constant of this class with the specified name.static IoPollLoopTime[]IoPollLoopTime.values()Returns an array containing the constants of this enum class, in the order they are declared.