Uses of Enum Class
org.refcodes.data.IoReconnectLoopTime
-
Uses of IoReconnectLoopTime in org.refcodes.data
Subclasses with type arguments of type IoReconnectLoopTime in org.refcodes.dataModifier and TypeClassDescriptionenumTheIoReconnectLoopTimedefined values used inside a control flow.Methods in org.refcodes.data that return IoReconnectLoopTimeModifier and TypeMethodDescriptionstatic IoReconnectLoopTimeReturns the enum constant of this class with the specified name.static IoReconnectLoopTime[]IoReconnectLoopTime.values()Returns an array containing the constants of this enum class, in the order they are declared.