Uses of Enum Class
org.refcodes.data.IoRetryCount
-
Uses of IoRetryCount in org.refcodes.data
Subclasses with type arguments of type IoRetryCount in org.refcodes.dataModifier and TypeClassDescriptionenumTheIoRetryCountdefined values used inside a control flow.Methods in org.refcodes.data that return IoRetryCountModifier and TypeMethodDescriptionstatic IoRetryCountReturns the enum constant of this class with the specified name.static IoRetryCount[]IoRetryCount.values()Returns an array containing the constants of this enum class, in the order they are declared.