Uses of Enum Class
org.refcodes.data.IoSleepLoopTime
-
Uses of IoSleepLoopTime in org.refcodes.data
Methods in org.refcodes.data that return IoSleepLoopTimeModifier and TypeMethodDescriptionstatic IoSleepLoopTimeReturns the enum constant of this class with the specified name.static IoSleepLoopTime[]IoSleepLoopTime.values()Returns an array containing the constants of this enum class, in the order they are declared.