Uses of Enum Class
org.refcodes.data.LatencySleepTime
-
Uses of LatencySleepTime in org.refcodes.data
Methods in org.refcodes.data that return LatencySleepTimeModifier and TypeMethodDescriptionstatic LatencySleepTimeReturns the enum constant of this class with the specified name.static LatencySleepTime[]LatencySleepTime.values()Returns an array containing the constants of this enum class, in the order they are declared.