Uses of Enum Class
org.refcodes.data.LoopExtensionTime
-
Uses of LoopExtensionTime in org.refcodes.data
Subclasses with type arguments of type LoopExtensionTime in org.refcodes.dataModifier and TypeClassDescriptionenumTheLoopExtensionTimedefined values used inside a control flow.Methods in org.refcodes.data that return LoopExtensionTimeModifier and TypeMethodDescriptionstatic LoopExtensionTimeReturns the enum constant of this class with the specified name.static LoopExtensionTime[]LoopExtensionTime.values()Returns an array containing the constants of this enum class, in the order they are declared.