Uses of Enum Class
org.refcodes.data.MarshalParameter
-
Uses of MarshalParameter in org.refcodes.data
Methods in org.refcodes.data that return MarshalParameterModifier and TypeMethodDescriptionstatic MarshalParameterReturns the enum constant of this class with the specified name.static MarshalParameter[]MarshalParameter.values()Returns an array containing the constants of this enum class, in the order they are declared.