Uses of Class
org.refcodes.data.MemoryUnit
-
-
Uses of MemoryUnit in org.refcodes.data
Methods in org.refcodes.data that return MemoryUnit Modifier and Type Method Description static MemoryUnitMemoryUnit. toSuitableUnit(long aBytes)Determines the best fitting unit to represent the given number of bytes in terms of "which memory unit is the biggest memory unit of which one unit is smaller than the given amount of bytes".static MemoryUnitMemoryUnit. toSuitableUnit(BigDecimal aBytes)Determines the best fitting unit to represent the given number of bytes in terms of "which memory unit is the biggest memory unit of which one unit is smaller than the given amount of bytes".static MemoryUnitMemoryUnit. valueOf(String name)Returns the enum constant of this type with the specified name.static MemoryUnit[]MemoryUnit. values()Returns an array containing the constants of this enum type, in the order they are declared.
-