Uses of Enum Class
org.refcodes.data.PaddingChar
-
Uses of PaddingChar in org.refcodes.data
Subclasses with type arguments of type PaddingChar in org.refcodes.dataModifier and TypeClassDescriptionenumCommonly used characters needful for analyzing, parsing or truncating texts.Methods in org.refcodes.data that return PaddingCharModifier and TypeMethodDescriptionstatic PaddingCharReturns the enum constant of this class with the specified name.static PaddingChar[]PaddingChar.values()Returns an array containing the constants of this enum class, in the order they are declared.