Uses of Enum Class
org.refcodes.data.Port

  • Uses of Port in org.refcodes.data

    Subclasses with type arguments of type Port in org.refcodes.data
    Modifier and Type
    Class
    Description
    enum 
    The Enum Port.
    Methods in org.refcodes.data that return Port
    Modifier and Type
    Method
    Description
    static Port
    Port.valueOf(String name)
    Returns the enum constant of this class with the specified name.
    static Port[]
    Port.values()
    Returns an array containing the constants of this enum class, in the order they are declared.