Uses of Enum Class
org.refcodes.data.Prefix

  • Uses of Prefix in org.refcodes.data

    Subclasses with type arguments of type Prefix in org.refcodes.data
    Modifier and Type
    Class
    Description
    enum 
    Commonly used prefixes needful for analyzing, parsing or truncating texts the like.
    Methods in org.refcodes.data that return Prefix
    Modifier and Type
    Method
    Description
    static Prefix
    Prefix.valueOf(String name)
    Returns the enum constant of this class with the specified name.
    static Prefix[]
    Prefix.values()
    Returns an array containing the constants of this enum class, in the order they are declared.