Uses of Enum Class
org.refcodes.data.RecoverySleepTime
-
Uses of RecoverySleepTime in org.refcodes.data
Subclasses with type arguments of type RecoverySleepTime in org.refcodes.dataModifier and TypeClassDescriptionenumTheRecoverySleepTimedefines values used to retry an operation in case an external system is not reachable.Methods in org.refcodes.data that return RecoverySleepTimeModifier and TypeMethodDescriptionstatic RecoverySleepTimeReturns the enum constant of this class with the specified name.static RecoverySleepTime[]RecoverySleepTime.values()Returns an array containing the constants of this enum class, in the order they are declared.