Uses of Enum Class
org.refcodes.data.RetryCount
-
Uses of RetryCount in org.refcodes.data
Subclasses with type arguments of type RetryCount in org.refcodes.dataMethods in org.refcodes.data that return RetryCountModifier and TypeMethodDescriptionstatic RetryCountReturns the enum constant of this class with the specified name.static RetryCount[]RetryCount.values()Returns an array containing the constants of this enum class, in the order they are declared.