Uses of Enum
org.refcodes.data.RetryLoopCount
-
Uses of RetryLoopCount in org.refcodes.data
Methods in org.refcodes.data that return RetryLoopCountModifier and TypeMethodDescriptionstatic RetryLoopCountReturns the enum constant of this type with the specified name.static RetryLoopCount[]RetryLoopCount.values()Returns an array containing the constants of this enum type, in the order they are declared.