Uses of Enum Class
org.refcodes.data.SafeInteger
-
Uses of SafeInteger in org.refcodes.data
Subclasses with type arguments of type SafeInteger in org.refcodes.dataModifier and TypeClassDescriptionenumTheSafeIntegerinterface defines some constants of interest related to the various number types available.Methods in org.refcodes.data that return SafeIntegerModifier and TypeMethodDescriptionstatic SafeIntegerReturns the enum constant of this class with the specified name.static SafeInteger[]SafeInteger.values()Returns an array containing the constants of this enum class, in the order they are declared.