Uses of Enum Class
org.refcodes.data.ScheduleSleepTime
-
Uses of ScheduleSleepTime in org.refcodes.data
Subclasses with type arguments of type ScheduleSleepTime in org.refcodes.dataModifier and TypeClassDescriptionenumTheScheduleSleepTimedefined values used inside a control flow.Methods in org.refcodes.data that return ScheduleSleepTimeModifier and TypeMethodDescriptionstatic ScheduleSleepTimeReturns the enum constant of this class with the specified name.static ScheduleSleepTime[]ScheduleSleepTime.values()Returns an array containing the constants of this enum class, in the order they are declared.