Uses of Enum Class
org.refcodes.data.Scheme
-
Uses of Scheme in org.refcodes.data
Subclasses with type arguments of type Scheme in org.refcodes.dataModifier and TypeClassDescriptionenumTheSchemedefine values useful when working with files or a file-system.Methods in org.refcodes.data that return SchemeModifier and TypeMethodDescriptionstatic SchemeReturns thatSchemerepresented by the given name.static SchemeScheme.fromProtocol(String aProtocol) Returns thatSchemerepresented by the given protocol.static SchemeScheme.fromScheme(String aUrl) Determines theSchemefrom the given URL.static SchemeReturns the enum constant of this class with the specified name.static Scheme[]Scheme.values()Returns an array containing the constants of this enum class, in the order they are declared.