Uses of Enum Class
org.refcodes.data.SleepLoopTime
-
Uses of SleepLoopTime in org.refcodes.data
Subclasses with type arguments of type SleepLoopTime in org.refcodes.dataModifier and TypeClassDescriptionenumTheSleepLoopTimedefined values used inside a control flow.Methods in org.refcodes.data that return SleepLoopTimeModifier and TypeMethodDescriptionstatic SleepLoopTimeReturns the enum constant of this class with the specified name.static SleepLoopTime[]SleepLoopTime.values()Returns an array containing the constants of this enum class, in the order they are declared.