Uses of Enum
org.refcodes.data.SystemProperty
-
Uses of SystemProperty in org.refcodes.data
Methods in org.refcodes.data that return SystemPropertyModifier and TypeMethodDescriptionstatic SystemPropertyReturns the enum constant of this type with the specified name.static SystemProperty[]SystemProperty.values()Returns an array containing the constants of this enum type, in the order they are declared.