Uses of Enum Class
org.refcodes.data.TextBorder
-
Uses of TextBorder in org.refcodes.data
Subclasses with type arguments of type TextBorder in org.refcodes.dataMethods in org.refcodes.data that return TextBorderModifier and TypeMethodDescriptionstatic TextBorderReturns the enum constant of this class with the specified name.static TextBorder[]TextBorder.values()Returns an array containing the constants of this enum class, in the order they are declared.