Uses of Enum Class
org.refcodes.data.Wildcard
-
Uses of Wildcard in org.refcodes.data
Subclasses with type arguments of type Wildcard in org.refcodes.dataModifier and TypeClassDescriptionenumCommonly used characters needful for analyzing, parsing or truncating texts.Methods in org.refcodes.data that return Wildcard