Package org.refcodes.data
package org.refcodes.data
-
ClassDescriptionThe
AckTimeoutdefines values used inside a Transmit/Acknowledge (ARQ) processing control flow.Defines enumeration elements for the left and the right side.Commonly used characters to be prefixed to annotations' names to distinguish them form element names and the like.This enumeration contains ANSI Escape-Codes for modifying the appearance of console output to ANSI enabled terminals.Commonly used prefixes needful for analyzing, parsing or truncating command line arguments and so on.This enumeration groupsArgsPrefixby platform.Some ASCII codes used by REFCODES.ORG artifacts.An enumeration for text palette definitions to make it easy working with such default palettes.Some values regarding binary numbers.The Enum BitMask.Some values's literal (String) representation useful when parsing or evaluating texts.Commonly used char sets.The Enum ConsoleDimension.TheDaemonLoopSleepTimedefined values used inside a control flow.Provides an accessor for a data locators property (array ofURLs andInputStreams).Provides a builder for a data locators property.Provides a mutator for a data locators property.Provides a property (getter / setter) for a data locators property (width and height).Provides an accessor for a data locator property (URLandInputStream).DataLocator.DataLocatorBuilder<B extends DataLocator.DataLocatorBuilder<B>>Provides a builder for a data locator property.Provides a mutator for a data locator property.Provides a property (getter / setter) for a data locator property (width and height).Commonly used characters when working with separated values or properties and the like making use of text separator characters .TheDelimitersgroupsDelimitervalues belonging somehow together or sharing a similar semantics.TheEncodingdefine values representing an encoding which are to be passed as argument to according methods.Commonly used characters for EOL markers in texts.TheEscapeCodeenumeration contains all of Java's escape codes (https://docs.oracle.com/javase/tutorial/java/data/characters.html) and the escape sequences (being the defused escape codes) as well as methods to retrieve the escape code from the escape sequence (as ofEscapeCode.toEscapeCode(String)) and vice versa (as ofEscapeCode.toEscapeCode(char)).Some default exit codes defined for CLI applications.TheFilenameExtensiondefine values useful when working with files or a file-system.A flag can be on or off.TheFolderdefine values useful when working with files or a file-system.TheFoldersdefine values useful when working with folders on a file-system.TheIoBlockSizedefined values used inside a control flow.TheIoHeurisitcsTimeToLivedefines values used to cache IO related heuristics (e.g. meta data of or for remote systems)TheIoPollLoopTimedefined values used when polling data from I/O, e.g. the file system or via TCP/IP.TheIoReconnectLoopTimedefined values used inside a control flow.TheIoRetryCountdefined values used inside a control flow.TheIoSleepLoopTimedefined values used inside a control flow.TheIoTimeoutdefines values used inside a IO processing control flow.TheLatencySleepTimedefined values used inside a control flow.Some licensing and copyright information asStringconstants.Some values's literal (String) representation useful when parsing or evaluating texts.TheLoopExtensionTimedefined values used inside a control flow.TheMemoryUnitprovides enumerations for common memory units alongside conversions to and from memory size specified in bytes.Commonly used characters needful for analyzing, parsing or truncating texts.Commonly used characters needful for analyzing, parsing or truncating texts.The Enum Port.Commonly used prefixes needful for analyzing, parsing or truncating texts the like.Commonly used characters needful for analyzing, parsing or truncating texts.TheRecoverySleepTimedefines values used to retry an operation in case an external system is not reachable.A text region has a beginning index being included by the region and an end index being excluded by the region and a resulting length.TheRetryCountdefined values used inside a control flow.TheRetryLoopCountdefined values used inside a control flow.TheSafeIntegerinterface defines some constants of interest related to the various number types available.TheScheduleSleepTimedefined values used inside a control flow.TheSchemedefine values useful when working with files or a file-system.TheSleepLoopTimedefined values used inside a control flow.Commonly used characters needful for analyzing, parsing or truncating texts.Commonly used text blocks in the code.The Enum TextBorder.Commonly used characters needful for analyzing, parsing or truncating texts.