Serializable, Comparable<Annotator>, org.refcodes.mixin.CharAccessorpublic enum Annotator extends Enum<Annotator> implements org.refcodes.mixin.CharAccessor
| Enum Constant | Description |
|---|---|
JAVA |
The annotation prefix used by the Java language ('@').
|
| Modifier and Type | Method | Description |
|---|---|---|
char |
getChar() |
|
static Annotator |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Annotator[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Annotator JAVA
public static Annotator[] values()
for (Annotator c : Annotator.values()) System.out.println(c);
public static Annotator valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic char getChar()
getChar in interface org.refcodes.mixin.CharAccessorCopyright © 2021. All rights reserved.