Serializable, Comparable<Integer>, org.refcodes.mixin.ValueAccessor<Integer>public enum Binary extends Enum<Binary> implements org.refcodes.mixin.ValueAccessor<Integer>
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>| Enum Constant | Description |
|---|---|
BITS_PER_BYTE |
|
BITS_PER_INT |
|
BYTES_PER_INT |
|
BYTES_PER_LONG |
| Modifier and Type | Method | Description |
|---|---|---|
Integer |
getValue() |
Gets the value.
|
static Binary |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Binary[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Binary BYTES_PER_INT
public static final Binary BYTES_PER_LONG
public static final Binary BITS_PER_BYTE
public static final Binary BITS_PER_INT
public static Binary[] values()
for (Binary c : Binary.values()) System.out.println(c);
public static Binary valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2021. All rights reserved.