Serializable, Comparable<BitMask>, org.refcodes.mixin.ValueAccessor<Long>public enum BitMask extends Enum<BitMask> implements org.refcodes.mixin.ValueAccessor<Long>
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>| Enum Constant | Description |
|---|---|
MASK_16 |
|
MASK_24 |
|
MASK_32 |
|
MASK_40 |
|
MASK_48 |
|
MASK_56 |
|
MASK_64 |
|
MASK_8 |
| Modifier and Type | Method | Description |
|---|---|---|
Long |
getValue() |
|
static BitMask |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static BitMask[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final BitMask MASK_8
public static final BitMask MASK_16
public static final BitMask MASK_24
public static final BitMask MASK_32
public static final BitMask MASK_40
public static final BitMask MASK_48
public static final BitMask MASK_56
public static final BitMask MASK_64
public static BitMask[] values()
for (BitMask c : BitMask.values()) System.out.println(c);
public static BitMask valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2018. All rights reserved.