Serializable, Comparable<BooleanLiterals>public enum BooleanLiterals extends Enum<BooleanLiterals>
String) representation useful when parsing or
evaluating texts.| Enum Constant | Description |
|---|---|
FALSE |
Strings representing a "false" boolean value.
|
TRUE |
Strings representing a "true" boolean value.
|
| Modifier and Type | Method | Description |
|---|---|---|
String[] |
getNames() |
An array of the names representing the set of folder names.
|
static boolean |
isFalse(String aValue) |
Returns true in case the given
String equals (ignoring the case)
one of the false literals as of FALSE and
getNames(). |
static boolean |
isTrue(String aValue) |
Returns true in case the given
String equals (ignoring the case)
one of the true literals as of TRUE and
getNames(). |
static BooleanLiterals |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static BooleanLiterals[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final BooleanLiterals TRUE
public static final BooleanLiterals FALSE
public static BooleanLiterals[] values()
for (BooleanLiterals c : BooleanLiterals.values()) System.out.println(c);
public static BooleanLiterals valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String[] getNames()
public static boolean isTrue(String aValue)
String equals (ignoring the case)
one of the true literals as of TRUE and
getNames().aValue - The value to be tested whether it represents a
true literal.true literal, else false.public static boolean isFalse(String aValue)
String equals (ignoring the case)
one of the false literals as of FALSE and
getNames().aValue - The value to be tested whether it represents a
false literal.false literal, else false.Copyright © 2021. All rights reserved.