Serializable, Comparable<CharSet>, org.refcodes.mixin.CharSetAccessorpublic enum CharSet extends Enum<CharSet> implements org.refcodes.mixin.CharSetAccessor
org.refcodes.mixin.CharSetAccessor.CharSetBuilder<B extends org.refcodes.mixin.CharSetAccessor.CharSetBuilder<B>>, org.refcodes.mixin.CharSetAccessor.CharSetMutator, org.refcodes.mixin.CharSetAccessor.CharSetProperty| Enum Constant | Description |
|---|---|
ALPHABETIC |
|
ALPHANUMERIC |
|
ARABIC_BASE64 |
|
ASCII |
|
BASE64 |
|
BASE64URL |
|
BINARY |
|
ENCODED_AS_NUMBER |
No prefixing zeros allowed when encoding a value to be stored by a (JSON)
number variable.
|
END_OF_LINE |
|
HEXADECIMAL |
|
LINE_BREAK_MARKERS |
When formatting texts, those chars can be used to identify a possible
suitable end of line (when seeking for a position to do a line-break).
|
LOWER_CASE |
|
NUMERIC |
|
QUOTES |
|
REGEX_SPECIAL_CHARS |
|
SPACE_MARKERS |
When formatting texts, those chars can be used to identify a space
between two words.
|
UPPER_CASE |
|
WHITE_SPACES |
| Modifier and Type | Method | Description |
|---|---|---|
char[] |
getCharSet() |
|
boolean |
hasChar(char aChar) |
Checks for char.
|
static CharSet |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static CharSet[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final CharSet ASCII
public static final CharSet ALPHABETIC
public static final CharSet UPPER_CASE
public static final CharSet LOWER_CASE
public static final CharSet ALPHANUMERIC
public static final CharSet NUMERIC
public static final CharSet ENCODED_AS_NUMBER
public static final CharSet BINARY
public static final CharSet HEXADECIMAL
public static final CharSet BASE64
public static final CharSet BASE64URL
public static final CharSet ARABIC_BASE64
public static final CharSet QUOTES
public static final CharSet WHITE_SPACES
public static final CharSet END_OF_LINE
public static final CharSet LINE_BREAK_MARKERS
public static final CharSet SPACE_MARKERS
public static final CharSet REGEX_SPECIAL_CHARS
public static CharSet[] values()
for (CharSet c : CharSet.values()) System.out.println(c);
public static CharSet valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic char[] getCharSet()
getCharSet in interface org.refcodes.mixin.CharSetAccessorpublic boolean hasChar(char aChar)
aChar - the charCopyright © 2018. All rights reserved.