Serializable, Comparable<CommandArgPrefix>, org.refcodes.mixin.PrefixAccessorpublic enum CommandArgPrefix extends Enum<CommandArgPrefix> implements org.refcodes.mixin.PrefixAccessor
| Enum Constant | Description |
|---|---|
POSIX_LONG_OPTION |
A command line argument (POSIX) long-option is prefixed with a double
hyphen-minus "--".
|
POSIX_SHORT_OPTION |
A command line argument (POSIX) short-option is prefixed with a single
hyphen-minus "-".
|
WINDOWS_OPTION |
A DOS box option is prefixed with a single slash "/".
|
| Modifier and Type | Method | Description |
|---|---|---|
String |
getPrefix() |
|
static String[] |
toPrefixes() |
Returns an array with all
String prefixes as of
getPrefix() defined by this enumeration. |
static CommandArgPrefix |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static CommandArgPrefix[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final CommandArgPrefix WINDOWS_OPTION
public static final CommandArgPrefix POSIX_SHORT_OPTION
public static final CommandArgPrefix POSIX_LONG_OPTION
public static CommandArgPrefix[] values()
for (CommandArgPrefix c : CommandArgPrefix.values()) System.out.println(c);
public static CommandArgPrefix valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getPrefix()
getPrefix in interface org.refcodes.mixin.PrefixAccessorpublic static String[] toPrefixes()
String prefixes as of
getPrefix() defined by this enumeration.Copyright © 2021. All rights reserved.