Serializable, Comparable<CommandArgPrefixes>public enum CommandArgPrefixes extends Enum<CommandArgPrefixes>
CommandArgPrefix by platform.| Enum Constant | Description |
|---|---|
POSIX |
Prefixes for command line arguments commonly used on POSIX conforming
systems.
|
WINDOWS |
Prefixes for command line arguments commonly used on Windows based
systems.
|
| Modifier and Type | Method | Description |
|---|---|---|
CommandArgPrefix[] |
getCommandArgPrefixes() |
Returns the related
CommandArgPrefix elements. |
String[] |
toPrefixes() |
Returns an array with all
String prefixes as of
CommandArgPrefix.getPrefix() defined by this enumeration. |
static CommandArgPrefixes |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static CommandArgPrefixes[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final CommandArgPrefixes WINDOWS
public static final CommandArgPrefixes POSIX
public static CommandArgPrefixes[] values()
for (CommandArgPrefixes c : CommandArgPrefixes.values()) System.out.println(c);
public static CommandArgPrefixes valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic CommandArgPrefix[] getCommandArgPrefixes()
CommandArgPrefix elements.CommandArgPrefix elements.public String[] toPrefixes()
String prefixes as of
CommandArgPrefix.getPrefix() defined by this enumeration.Copyright © 2021. All rights reserved.