Serializable, Comparable<ConsoleDimension>, org.refcodes.mixin.ValueAccessor<Integer>public enum ConsoleDimension extends Enum<ConsoleDimension> implements org.refcodes.mixin.ValueAccessor<Integer>
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>| Enum Constant | Description |
|---|---|
MAX_HEIGHT |
|
MAX_WIDTH |
|
MIN_HEIGHT |
|
MIN_WIDTH |
|
NORM_HEIGHT |
|
NORM_WIDTH |
| Modifier and Type | Method | Description |
|---|---|---|
Integer |
getValue() |
Gets the value.
|
static ConsoleDimension |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static ConsoleDimension[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final ConsoleDimension MIN_WIDTH
public static final ConsoleDimension NORM_WIDTH
public static final ConsoleDimension MAX_WIDTH
public static final ConsoleDimension MIN_HEIGHT
public static final ConsoleDimension NORM_HEIGHT
public static final ConsoleDimension MAX_HEIGHT
public static ConsoleDimension[] values()
for (ConsoleDimension c : ConsoleDimension.values()) System.out.println(c);
public static ConsoleDimension valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2018. All rights reserved.