Serializable, Comparable<Delimiters>public enum Delimiters extends Enum<Delimiters>
Delimiters groups Delimiter values belonging somehow
together or sharing a similar semantics.| Enum Constant | Description |
|---|---|
PATHS |
| Modifier and Type | Method | Description |
|---|---|---|
boolean |
hasDelimiter(char aDelimiter) |
Tests if the given delimiter is contained in the
Delimiters
definition. |
boolean |
hasDelimiter(Delimiter aDelimiter) |
Tests if the given delimiter is contained in the
Delimiters
definition. |
char[] |
toChars() |
Contains an array of the characters representing the delimiters in this
grouping enumeration.
|
static Delimiters |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Delimiters[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Delimiters PATHS
public static Delimiters[] values()
for (Delimiters c : Delimiters.values()) System.out.println(c);
public static Delimiters valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic boolean hasDelimiter(char aDelimiter)
Delimiters
definition.aDelimiter - the delimiterDelimiters definition, else false.public boolean hasDelimiter(Delimiter aDelimiter)
Delimiters
definition.aDelimiter - the delimiterDelimiters definition, else false.public char[] toChars()
Copyright © 2018. All rights reserved.