Serializable, Comparable<EndOfLine>, org.refcodes.mixin.CharAccessorpublic enum EndOfLine extends Enum<EndOfLine> implements org.refcodes.mixin.CharAccessor
| Enum Constant | Description |
|---|---|
CARRIAGE_RETURN |
|
LINE_FEED |
| Modifier and Type | Method | Description |
|---|---|---|
char |
getChar() |
|
static boolean |
isEndOfLine(char aEndOfLine) |
Tests if the given potential EOL character is contained in the
EndOfLine enumeration. |
static char[] |
toChars() |
Returns an array of the characters representing the EOL characters in
this grouping enumeration.
|
static EndOfLine |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static EndOfLine[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final EndOfLine CARRIAGE_RETURN
public static final EndOfLine LINE_FEED
public static EndOfLine[] values()
for (EndOfLine c : EndOfLine.values()) System.out.println(c);
public static EndOfLine valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic char getChar()
getChar in interface org.refcodes.mixin.CharAccessorpublic static boolean isEndOfLine(char aEndOfLine)
EndOfLine enumeration.aEndOfLine - the potential EOL characterEndOfLine enumeration, else false.public static char[] toChars()
Copyright © 2021. All rights reserved.