public enum EnvironmentProperty extends Enum<EnvironmentProperty> implements org.refcodes.mixin.KeyAccessor<String>, org.refcodes.mixin.ValueAccessor<String>
EnvironmentProperty for retrieving some common environment variables
with ease.| Enum Constant and Description |
|---|
COMPUTERNAME
The environment variable (on windows) holding the computer's name.
|
CONSOLE_HEIGHT
The console height environment variable.
|
CONSOLE_WIDTH
The console width environment variable on *ix like shells.
|
USER_HOME
Environment variable holding the user's home folder path.
|
| Modifier and Type | Method and Description |
|---|---|
String |
getKey() |
String |
getValue() |
static EnvironmentProperty |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static EnvironmentProperty[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final EnvironmentProperty CONSOLE_HEIGHT
public static final EnvironmentProperty CONSOLE_WIDTH
public static final EnvironmentProperty COMPUTERNAME
public static final EnvironmentProperty USER_HOME
public static EnvironmentProperty[] values()
for (EnvironmentProperty c : EnvironmentProperty.values()) System.out.println(c);
public static EnvironmentProperty valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getKey()
getKey in interface org.refcodes.mixin.KeyAccessor<String>Copyright © 2016. All rights reserved.