Serializable, Comparable<Flag>public enum Flag extends Enum<Flag>
| Modifier and Type | Method | Description |
|---|---|---|
static Flag |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Flag[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static Flag[] values()
for (Flag c : Flag.values()) System.out.println(c);
public static Flag valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2021. All rights reserved.