Serializable, Comparable<Folder>, org.refcodes.mixin.NameAccessorpublic enum Folder extends Enum<Folder> implements org.refcodes.mixin.NameAccessor
Folder define values useful when working with files or a
file-system.| Enum Constant | Description |
|---|---|
CACHE |
|
CLASSES |
|
CONFIG |
|
ETC |
|
HIDDEN_CONFIG |
|
HIDDEN_SETTINGS |
|
REFCODES |
|
SETTINGS |
|
TARGET |
|
TEST_CLASSES |
| Modifier and Type | Method | Description |
|---|---|---|
String |
getName() |
|
static Folder |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Folder[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Folder CONFIG
public static final Folder ETC
public static final Folder SETTINGS
public static final Folder CACHE
public static final Folder REFCODES
public static final Folder HIDDEN_CONFIG
public static final Folder HIDDEN_SETTINGS
public static final Folder TARGET
public static final Folder CLASSES
public static final Folder TEST_CLASSES
public static Folder[] values()
for (Folder c : Folder.values()) System.out.println(c);
public static Folder valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getName()
getName in interface org.refcodes.mixin.NameAccessorCopyright © 2018. All rights reserved.