Serializable, Comparable<IoBlockSize>, org.refcodes.mixin.SizeAccessorpublic enum IoBlockSize extends Enum<IoBlockSize> implements org.refcodes.mixin.SizeAccessor
IoBlockSize defined values used inside a control flow.| Modifier and Type | Method | Description |
|---|---|---|
long |
getSize() |
|
static IoBlockSize |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static IoBlockSize[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final IoBlockSize MIN
public static final IoBlockSize NORM
public static final IoBlockSize MAX
public static IoBlockSize[] values()
for (IoBlockSize c : IoBlockSize.values()) System.out.println(c);
public static IoBlockSize valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic long getSize()
getSize in interface org.refcodes.mixin.SizeAccessorCopyright © 2018. All rights reserved.