Serializable, Comparable<IoPollLoopTime>, org.refcodes.mixin.TimeInMsAccessorpublic enum IoPollLoopTime extends Enum<IoPollLoopTime> implements org.refcodes.mixin.TimeInMsAccessor
IoPollLoopTime defined values used when polling data from I/O,
e.g. the file system or via TCP/IP.org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B extends org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B>>, org.refcodes.mixin.TimeInMsAccessor.TimeInMsMutator, org.refcodes.mixin.TimeInMsAccessor.TimeInMsProperty| Modifier and Type | Method | Description |
|---|---|---|
int |
getTimeInMs() |
|
static IoPollLoopTime |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static IoPollLoopTime[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final IoPollLoopTime MIN
public static final IoPollLoopTime NORM
public static final IoPollLoopTime MAX
public static IoPollLoopTime[] values()
for (IoPollLoopTime c : IoPollLoopTime.values()) System.out.println(c);
public static IoPollLoopTime valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic int getTimeInMs()
getTimeInMs in interface org.refcodes.mixin.TimeInMsAccessorCopyright © 2021. All rights reserved.