Serializable, Comparable<IoSleepLoopTime>, org.refcodes.mixin.TimeInMsAccessorpublic enum IoSleepLoopTime extends Enum<IoSleepLoopTime> implements org.refcodes.mixin.TimeInMsAccessor
IoSleepLoopTime defined values used inside a control flow.org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B extends org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B>>, org.refcodes.mixin.TimeInMsAccessor.TimeInMsMutator, org.refcodes.mixin.TimeInMsAccessor.TimeInMsProperty| Modifier and Type | Method | Description |
|---|---|---|
int |
getTimeInMs() |
|
static IoSleepLoopTime |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static IoSleepLoopTime[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final IoSleepLoopTime MIN
public static final IoSleepLoopTime NORM
public static final IoSleepLoopTime MAX
public static IoSleepLoopTime[] values()
for (IoSleepLoopTime c : IoSleepLoopTime.values()) System.out.println(c);
public static IoSleepLoopTime valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic int getTimeInMs()
getTimeInMs in interface org.refcodes.mixin.TimeInMsAccessorCopyright © 2021. All rights reserved.