Serializable, Comparable<IoTimeout>, org.refcodes.mixin.TimeInMsAccessorpublic enum IoTimeout extends Enum<IoTimeout> implements org.refcodes.mixin.TimeInMsAccessor
IoTimeout defines values used inside a IO processing control
flow.org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B extends org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B>>, org.refcodes.mixin.TimeInMsAccessor.TimeInMsMutator, org.refcodes.mixin.TimeInMsAccessor.TimeInMsProperty| Modifier and Type | Field | Description |
|---|---|---|
static int |
TIMEOUT_DIVIDER |
| Modifier and Type | Method | Description |
|---|---|---|
int |
getTimeInMs() |
|
static long |
toSenseTimeoutTimeframeInMs(long aIoTimeoutInMs) |
Determines the timeout to securely sense for a given timeout.
|
static long |
toTimeoutSleepLoopTimeInMs(long aIoTimeoutInMs) |
Determines the sleep time within an I/O polling timeout loop.
|
static IoTimeout |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static IoTimeout[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final IoTimeout MIN
public static final IoTimeout NORM
public static final IoTimeout MAX
public static final int TIMEOUT_DIVIDER
public static IoTimeout[] values()
for (IoTimeout c : IoTimeout.values()) System.out.println(c);
public static IoTimeout valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic int getTimeInMs()
getTimeInMs in interface org.refcodes.mixin.TimeInMsAccessorpublic static long toTimeoutSleepLoopTimeInMs(long aIoTimeoutInMs)
aIoTimeoutInMs - The overall I/O timeout.public static long toSenseTimeoutTimeframeInMs(long aIoTimeoutInMs)
aIoTimeoutInMs - The overall I/O timeout within which to sense.Copyright © 2021. All rights reserved.