Serializable, Comparable<LatencySleepTime>, org.refcodes.mixin.TimeInMsAccessorpublic enum LatencySleepTime extends Enum<LatencySleepTime> implements org.refcodes.mixin.TimeInMsAccessor
LatencySleepTime defined values used inside a control flow.org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B extends org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B>>, org.refcodes.mixin.TimeInMsAccessor.TimeInMsMutator, org.refcodes.mixin.TimeInMsAccessor.TimeInMsProperty| Modifier and Type | Method | Description |
|---|---|---|
int |
getTimeInMs() |
|
static LatencySleepTime |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static LatencySleepTime[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final LatencySleepTime MIN
public static final LatencySleepTime NORM
public static final LatencySleepTime MAX
public static LatencySleepTime[] values()
for (LatencySleepTime c : LatencySleepTime.values()) System.out.println(c);
public static LatencySleepTime valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic int getTimeInMs()
getTimeInMs in interface org.refcodes.mixin.TimeInMsAccessorCopyright © 2021. All rights reserved.