Enum License

  • All Implemented Interfaces:
    Serializable, Comparable<License>, org.refcodes.mixin.TextAccessor


    public enum License
    extends Enum<License>
    implements org.refcodes.mixin.TextAccessor
    Some licensing and copyright information as String constants.
    • Enum Constant Detail

      • REFCODES_LICENSE

        public static final License REFCODES_LICENSE
      • LICENSE_NOTE

        public static final License LICENSE_NOTE
      • COPYRIGHT_NOTE

        public static final License COPYRIGHT_NOTE
    • Method Detail

      • values

        public static License[] values​()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (License c : License.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static License valueOf​(String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null
      • getText

        public String getText​()
        Specified by:
        getText in interface org.refcodes.mixin.TextAccessor