Serializable, Comparable<Literals>public enum Literals extends Enum<Literals>
String) representation useful when parsing or
evaluating texts.| Enum Constant | Description |
|---|---|
FALSE |
Strings representing a "false" boolean value.
|
TRUE |
Strings representing a "true" boolean value.
|
| Modifier and Type | Method | Description |
|---|---|---|
String[] |
getNames() |
An array of the names representing the set of folder names.
|
static Literals |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Literals[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Literals TRUE
public static final Literals FALSE
public static Literals[] values()
for (Literals c : Literals.values()) System.out.println(c);
public static Literals valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String[] getNames()
Copyright © 2018. All rights reserved.