Serializable, Comparable<LoopExtensionTime>, org.refcodes.mixin.TimeInMsAccessorpublic enum LoopExtensionTime extends Enum<LoopExtensionTime> implements org.refcodes.mixin.TimeInMsAccessor
LoopExtensionTime defined values used inside a control flow.org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B extends org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B>>, org.refcodes.mixin.TimeInMsAccessor.TimeInMsMutator, org.refcodes.mixin.TimeInMsAccessor.TimeInMsProperty| Enum Constant | Description |
|---|---|
MAX |
A retry is being extended for each retry by an exponential delay
extension time (when > 0): long theDelay((long) ( Math.pow(4,
theRetries++ ) * EXTENSION_TIME ))), See also
http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdf |
MIN |
A retry is being extended for each retry by an exponential delay
extension time (when > 0): long theDelay((long) ( Math.pow(4,
theRetries++ ) * EXTENSION_TIME ))), Also see
http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdf |
NORM |
A retry is being extended for each retry by an exponential delay
extension time (when > 0): long theDelay((long) ( Math.pow(4,
theRetries++ ) * EXTENSION_TIME ))), Also see
http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdf |
| Modifier and Type | Method | Description |
|---|---|---|
int |
getTimeInMs() |
|
static LoopExtensionTime |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static LoopExtensionTime[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final LoopExtensionTime MIN
http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdfpublic static final LoopExtensionTime NORM
http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdfpublic static final LoopExtensionTime MAX
http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdfpublic static LoopExtensionTime[] values()
for (LoopExtensionTime c : LoopExtensionTime.values()) System.out.println(c);
public static LoopExtensionTime valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic int getTimeInMs()
getTimeInMs in interface org.refcodes.mixin.TimeInMsAccessorCopyright © 2021. All rights reserved.