Serializable, Comparable<LoopSleepTime>, org.refcodes.mixin.MillisecondsAccessorpublic enum LoopSleepTime extends Enum<LoopSleepTime> implements org.refcodes.mixin.MillisecondsAccessor
LoopSleepTime defined values used inside a control flow.org.refcodes.mixin.MillisecondsAccessor.MillisecondsBuilder<B extends org.refcodes.mixin.MillisecondsAccessor.MillisecondsBuilder<B>>, org.refcodes.mixin.MillisecondsAccessor.MillisecondsMutator, org.refcodes.mixin.MillisecondsAccessor.MillisecondsProperty| Modifier and Type | Method | Description |
|---|---|---|
int |
getMilliseconds() |
|
static LoopSleepTime |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static LoopSleepTime[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final LoopSleepTime MIN
public static final LoopSleepTime NORM
public static final LoopSleepTime MAX
public static LoopSleepTime[] values()
for (LoopSleepTime c : LoopSleepTime.values()) System.out.println(c);
public static LoopSleepTime valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic int getMilliseconds()
getMilliseconds in interface org.refcodes.mixin.MillisecondsAccessorCopyright © 2018. All rights reserved.