Serializable, Comparable<MarshalParameter>, org.refcodes.mixin.NameAccessorpublic enum MarshalParameter extends Enum<MarshalParameter> implements org.refcodes.mixin.NameAccessor
MarshalParameter defines common parameters (parameter is considered
the key of a key/value pair) of a given semantics for the according property.| Enum Constant | Description |
|---|---|
BASE_URL |
A base URL may be stored in such a property.
|
CHARSET |
Identifies a charset code such as
Encoding.UTF_8's
Encoding.getCode(). |
COMMENT |
Identifies a comment
String. |
DELIMITER |
The value of such a property identifies a single delimiter char.
|
DELIMITERS |
The value of such a property identifies a multiple delimiter chars.
|
ENCODING |
Identifies the encoding such as
Encoding.UTF_8. |
HEADER |
E.g. used in an XML file's head's declaration such as
<? |
ROOT_ELEMENT |
The root element to be used when marshaling a structure to a notation
which requires a root element.
|
STAND_ALONE |
E.g. used in an XML file's head's declaration such as
<? |
VERSION |
Identifies a version, such as an XML version (depends on the notation to
which to marshal).
|
| Modifier and Type | Method | Description |
|---|---|---|
String |
getName() |
|
static MarshalParameter |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static MarshalParameter[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final MarshalParameter CHARSET
Encoding.UTF_8's
Encoding.getCode().public static final MarshalParameter BASE_URL
public static final MarshalParameter DELIMITER
public static final MarshalParameter DELIMITERS
public static final MarshalParameter COMMENT
String.public static final MarshalParameter ENCODING
Encoding.UTF_8.public static final MarshalParameter VERSION
public static final MarshalParameter ROOT_ELEMENT
public static final MarshalParameter STAND_ALONE
<?xml ecnoding="UTF-8" version="1.0" standalone="yes"?>
to determine whether this is a stand alone document (note that it is
declared as "standalone"!).public static final MarshalParameter HEADER
<?xml ecnoding="UTF-8" version="1.0" standalone="yes"?>public static MarshalParameter[] values()
for (MarshalParameter c : MarshalParameter.values()) System.out.println(c);
public static MarshalParameter valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getName()
getName in interface org.refcodes.mixin.NameAccessorCopyright © 2021. All rights reserved.