Serializable, Comparable<MoreText>, org.refcodes.mixin.CharAccessorpublic enum MoreText extends Enum<MoreText> implements org.refcodes.mixin.CharAccessor
| Enum Constant | Description |
|---|---|
MORE_TEXT_AFTER |
|
MORE_TEXT_BEFORE |
| Modifier and Type | Method | Description |
|---|---|---|
char |
getChar() |
|
static MoreText |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static MoreText[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final MoreText MORE_TEXT_BEFORE
public static final MoreText MORE_TEXT_AFTER
public static MoreText[] values()
for (MoreText c : MoreText.values()) System.out.println(c);
public static MoreText valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic char getChar()
getChar in interface org.refcodes.mixin.CharAccessorCopyright © 2021. All rights reserved.