Serializable, Comparable<Padding>, org.refcodes.mixin.CharAccessorpublic enum Padding extends Enum<Padding> implements org.refcodes.mixin.CharAccessor
| Enum Constant | Description |
|---|---|
BASE64 |
| Modifier and Type | Method | Description |
|---|---|---|
char |
getChar() |
|
static Padding |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Padding[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Padding BASE64
public static Padding[] values()
for (Padding c : Padding.values()) System.out.println(c);
public static Padding valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic char getChar()
getChar in interface org.refcodes.mixin.CharAccessorCopyright © 2018. All rights reserved.