Serializable, Comparable<PaddingChar>, org.refcodes.mixin.CharAccessorpublic enum PaddingChar extends Enum<PaddingChar> implements org.refcodes.mixin.CharAccessor
| Enum Constant | Description |
|---|---|
BASE64 |
| Modifier and Type | Method | Description |
|---|---|---|
char |
getChar() |
|
static PaddingChar |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static PaddingChar[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final PaddingChar BASE64
public static PaddingChar[] values()
for (PaddingChar c : PaddingChar.values()) System.out.println(c);
public static PaddingChar valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic char getChar()
getChar in interface org.refcodes.mixin.CharAccessorCopyright © 2021. All rights reserved.