Serializable, Comparable<PollLoopTime>, org.refcodes.mixin.MillisecondsAccessorpublic enum PollLoopTime extends Enum<PollLoopTime> implements org.refcodes.mixin.MillisecondsAccessor
PollLoopTime defined values used when polling data from I/O, e.g.
the file system or via TCP/IP.org.refcodes.mixin.MillisecondsAccessor.MillisecondsBuilder<B extends org.refcodes.mixin.MillisecondsAccessor.MillisecondsBuilder<B>>, org.refcodes.mixin.MillisecondsAccessor.MillisecondsMutator, org.refcodes.mixin.MillisecondsAccessor.MillisecondsProperty| Modifier and Type | Method | Description |
|---|---|---|
int |
getMilliseconds() |
|
static PollLoopTime |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static PollLoopTime[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final PollLoopTime MIN
public static final PollLoopTime NORM
public static final PollLoopTime MAX
public static PollLoopTime[] values()
for (PollLoopTime c : PollLoopTime.values()) System.out.println(c);
public static PollLoopTime valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic int getMilliseconds()
getMilliseconds in interface org.refcodes.mixin.MillisecondsAccessorCopyright © 2018. All rights reserved.