Serializable, Comparable<Prefix>, org.refcodes.mixin.PrefixAccessorpublic enum Prefix extends Enum<Prefix> implements org.refcodes.mixin.PrefixAccessor
| Enum Constant | Description |
|---|---|
ANNOTATION |
|
CSV_COMMENT |
|
DECRYPT |
|
ENCRYPT |
|
ENCRYPTED |
|
JAVA_PROPERTIES_COMMENT |
| Modifier and Type | Method | Description |
|---|---|---|
String |
getPrefix() |
|
static Prefix |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Prefix[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Prefix ENCRYPTED
public static final Prefix ENCRYPT
public static final Prefix DECRYPT
public static final Prefix JAVA_PROPERTIES_COMMENT
public static final Prefix CSV_COMMENT
public static final Prefix ANNOTATION
public static Prefix[] values()
for (Prefix c : Prefix.values()) System.out.println(c);
public static Prefix valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getPrefix()
getPrefix in interface org.refcodes.mixin.PrefixAccessorCopyright © 2021. All rights reserved.