public enum Prefixes extends Enum<Prefixes>
| Enum Constant and Description |
|---|
ARG_OPTION
All option prefixes as defines by this
Prefixes interface; being
the Prefix.SHORT_ARG_OPTION and the
Prefix.LONG_ARG_OPTION. |
| Modifier and Type | Method and Description |
|---|---|
String[] |
getPrefixes()
Gets the prefixes.
|
static Prefixes |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Prefixes[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Prefixes ARG_OPTION
Prefixes interface; being
the Prefix.SHORT_ARG_OPTION and the
Prefix.LONG_ARG_OPTION.public static Prefixes[] values()
for (Prefixes c : Prefixes.values()) System.out.println(c);
public static Prefixes valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String[] getPrefixes()
Copyright © 2018. All rights reserved.