Serializable, Comparable<Integer>, org.refcodes.mixin.ValueAccessor<Integer>public enum RetryCount extends Enum<RetryCount> implements org.refcodes.mixin.ValueAccessor<Integer>
RetryCount defined values used inside a control flow.org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>| Modifier and Type | Method | Description |
|---|---|---|
Integer |
getValue() |
|
static RetryCount |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static RetryCount[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final RetryCount MIN
public static final RetryCount NORM
public static final RetryCount MAX
public static RetryCount[] values()
for (RetryCount c : RetryCount.values()) System.out.println(c);
public static RetryCount valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2021. All rights reserved.