Serializable, Comparable<RetryLoopCount>, org.refcodes.mixin.NumberAccessor<Integer>public enum RetryLoopCount extends Enum<RetryLoopCount> implements org.refcodes.mixin.NumberAccessor<Integer>
RetryLoopCount defined values used inside a control flow.org.refcodes.mixin.NumberAccessor.NumberBuilder<V extends Object,B extends org.refcodes.mixin.NumberAccessor.NumberBuilder<V,B>>, org.refcodes.mixin.NumberAccessor.NumberMutator<V extends Object>, org.refcodes.mixin.NumberAccessor.NumberProperty<V extends Object>| Enum Constant | Description |
|---|---|
MAX_NUM_RETRY_LOOPS |
|
MIN_NUM_RETRY_LOOPS |
|
NORM_NUM_RETRY_LOOPS |
| Modifier and Type | Method | Description |
|---|---|---|
Integer |
getNumber() |
|
static RetryLoopCount |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static RetryLoopCount[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final RetryLoopCount MIN_NUM_RETRY_LOOPS
public static final RetryLoopCount NORM_NUM_RETRY_LOOPS
public static final RetryLoopCount MAX_NUM_RETRY_LOOPS
public static RetryLoopCount[] values()
for (RetryLoopCount c : RetryLoopCount.values()) System.out.println(c);
public static RetryLoopCount valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2018. All rights reserved.