Serializable, Comparable<ScheduleSleepTime>, org.refcodes.mixin.MillisecondsAccessorpublic enum ScheduleSleepTime extends Enum<ScheduleSleepTime> implements org.refcodes.mixin.MillisecondsAccessor
ScheduleSleepTime defined values used inside a control flow.org.refcodes.mixin.MillisecondsAccessor.MillisecondsBuilder<B extends org.refcodes.mixin.MillisecondsAccessor.MillisecondsBuilder<B>>, org.refcodes.mixin.MillisecondsAccessor.MillisecondsMutator, org.refcodes.mixin.MillisecondsAccessor.MillisecondsProperty| Enum Constant | Description |
|---|---|
MAX_SCHEDULE_SLEEP_TIME_IN_MS |
|
MIN_SCHEDULE_SLEEP_TIME_IN_MS |
|
NORM_SCHEDULE_SLEEP_TIME_IN_MS |
| Modifier and Type | Method | Description |
|---|---|---|
int |
getMilliseconds() |
|
static ScheduleSleepTime |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static ScheduleSleepTime[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final ScheduleSleepTime MIN_SCHEDULE_SLEEP_TIME_IN_MS
public static final ScheduleSleepTime NORM_SCHEDULE_SLEEP_TIME_IN_MS
public static final ScheduleSleepTime MAX_SCHEDULE_SLEEP_TIME_IN_MS
public static ScheduleSleepTime[] values()
for (ScheduleSleepTime c : ScheduleSleepTime.values()) System.out.println(c);
public static ScheduleSleepTime valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic int getMilliseconds()
getMilliseconds in interface org.refcodes.mixin.MillisecondsAccessorCopyright © 2018. All rights reserved.