Serializable, Comparable<SleepLoopTime>, org.refcodes.mixin.TimeInMsAccessorpublic enum SleepLoopTime extends Enum<SleepLoopTime> implements org.refcodes.mixin.TimeInMsAccessor
SleepLoopTime defined values used inside a control flow.org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B extends org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B>>, org.refcodes.mixin.TimeInMsAccessor.TimeInMsMutator, org.refcodes.mixin.TimeInMsAccessor.TimeInMsProperty| Modifier and Type | Method | Description |
|---|---|---|
int |
getTimeInMs() |
|
static SleepLoopTime |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static SleepLoopTime[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final SleepLoopTime MIN
public static final SleepLoopTime NORM
public static final SleepLoopTime MAX
public static SleepLoopTime[] values()
for (SleepLoopTime c : SleepLoopTime.values()) System.out.println(c);
public static SleepLoopTime valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic int getTimeInMs()
getTimeInMs in interface org.refcodes.mixin.TimeInMsAccessorCopyright © 2021. All rights reserved.