Serializable, Comparable<Suffix>, org.refcodes.mixin.SuffixAccessorpublic enum Suffix extends Enum<Suffix> implements org.refcodes.mixin.SuffixAccessor
| Enum Constant | Description |
|---|---|
PROTOCOL |
| Modifier and Type | Method | Description |
|---|---|---|
String |
getSuffix() |
|
static Suffix |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Suffix[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Suffix PROTOCOL
public static Suffix[] values()
for (Suffix c : Suffix.values()) System.out.println(c);
public static Suffix valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getSuffix()
getSuffix in interface org.refcodes.mixin.SuffixAccessorCopyright © 2018. All rights reserved.