public enum SystemProperty extends Enum<SystemProperty> implements org.refcodes.mixin.NameAccessor
SystemProperty define values to be used at runtime. Them are passed
to a JVM by prefixing a "-D" to the actual "property=value" pair.| Enum Constant and Description |
|---|
CONFIG_DIR
Pass as JVM argument via "-Dconfig.dir=path_to_your_config_dir" (where
path_to_your_config_dir stands for the path to the directory where you
placed configuration files such as the "runtimelogger-config.xml" file).
|
CONSOLE_HEIGHT
Pass as JVM argument via "-Dconsole.height=n" (where n stands for the
number of lines).
|
CONSOLE_WIDTH
Pass as JVM argument via "-Dconsole.width=n" (where n stands for the
number of chars per row).
|
FILE_SEPARATOR
The OS specific file separator is retrieved by this system property.
|
LINE_SEPARATOR |
OPERATING_SYSTEM_NAME |
PROCESS_ID
At least set on Ubuntu Linux:
|
TEMP_DIR
The OS specific temp folder path.
|
USER_HOME
System variable holding the user's home folder path.
|
| Modifier and Type | Method and Description |
|---|---|
String |
getName() |
String |
toValue()
Retrieves the system property value identified by the system propertie's
name.
|
static SystemProperty |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static SystemProperty[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final SystemProperty CONFIG_DIR
public static final SystemProperty FILE_SEPARATOR
System.getProperty(String).public static final SystemProperty TEMP_DIR
public static final SystemProperty PROCESS_ID
public static final SystemProperty LINE_SEPARATOR
public static final SystemProperty OPERATING_SYSTEM_NAME
public static final SystemProperty CONSOLE_HEIGHT
public static final SystemProperty CONSOLE_WIDTH
public static final SystemProperty USER_HOME
public static SystemProperty[] values()
for (SystemProperty c : SystemProperty.values()) System.out.println(c);
public static SystemProperty valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getName()
getName in interface org.refcodes.mixin.NameAccessorpublic String toValue()
Copyright © 2016. All rights reserved.