public enum Text extends Enum<Text> implements org.refcodes.mixin.TextAccessor
| Enum Constant and Description |
|---|
ARECIBO_MESSAGE |
ILLEGAL_STATE |
LICENSE |
NOT_YET_IMPLEMENTED |
NULL_VALUE |
REFCODES_ORG |
UNSUPPORTED_OPERATION |
| Modifier and Type | Method and Description |
|---|---|
String |
getText()
Gets the text.
|
String |
toString()
To string.
|
String[] |
toStrings()
Returns the text block representation of this element.
|
static Text |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Text[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Text REFCODES_ORG
public static final Text UNSUPPORTED_OPERATION
public static final Text ILLEGAL_STATE
public static final Text NOT_YET_IMPLEMENTED
public static final Text NULL_VALUE
public static final Text LICENSE
public static final Text ARECIBO_MESSAGE
public static Text[] values()
for (Text c : Text.values()) System.out.println(c);
public static Text valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getText()
getText in interface org.refcodes.mixin.TextAccessorpublic String toString()
public String[] toStrings()
Copyright © 2017. All rights reserved.