Serializable, Comparable<String>, org.refcodes.mixin.ValueAccessor<String>public enum Wildcard extends Enum<Wildcard> implements org.refcodes.mixin.ValueAccessor<String>
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>| Modifier and Type | Method | Description |
|---|---|---|
String |
getValue() |
|
static Wildcard |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Wildcard[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Wildcard CHAR
public static final Wildcard FILE
public static final Wildcard PATH
public static final Wildcard QUERY
public static Wildcard[] values()
for (Wildcard c : Wildcard.values()) System.out.println(c);
public static Wildcard valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2021. All rights reserved.