| Modifier and Type | Method | Description |
|---|---|---|
static AnsiEscapeCode |
AnsiEscapeCode.valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static AnsiEscapeCode[] |
AnsiEscapeCode.values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method | Description |
|---|---|---|
static String |
AnsiEscapeCode.toEscapeSequence(AnsiEscapeCode... aAnsiEscapeCodes) |
Basic functionality to create an ANSI Escape-Code sequence from the
provided
AnsiEscapeCode elements directly printable to
System.out. |
Copyright © 2021. All rights reserved.