Uses of Class
org.refcodes.data.CommandArgPrefix
-
-
Uses of CommandArgPrefix in org.refcodes.data
Methods in org.refcodes.data that return CommandArgPrefix Modifier and Type Method Description CommandArgPrefix[]CommandArgPrefixes. getCommandArgPrefixes()Returns the relatedCommandArgPrefixelements.static CommandArgPrefixCommandArgPrefix. valueOf(java.lang.String name)Returns the enum constant of this type with the specified name.static CommandArgPrefix[]CommandArgPrefix. values()Returns an array containing the constants of this enum type, in the order they are declared.
-