Uses of Class
org.refcodes.data.CommonParameter
-
-
Uses of CommonParameter in org.refcodes.data
Methods in org.refcodes.data that return CommonParameter Modifier and Type Method Description static CommonParameterCommonParameter. valueOf(java.lang.String name)Returns the enum constant of this type with the specified name.static CommonParameter[]CommonParameter. values()Returns an array containing the constants of this enum type, in the order they are declared.
-