| Modifier and Type | Method and Description |
|---|---|
static LoopSleepTime |
LoopSleepTime.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static LoopSleepTime[] |
LoopSleepTime.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
Copyright © 2017. All rights reserved.