| Modifier and Type | Method | Description |
|---|---|---|
static Port |
Port.valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Port[] |
Port.values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
Copyright © 2021. All rights reserved.