| Modifier and Type | Method | Description |
|---|---|---|
static Scheme |
Scheme.fromName(String aName) |
Returns that
Scheme represented by the given name. |
static Scheme |
Scheme.fromProtocol(String aProtocol) |
Returns that
Scheme represented by the given protocol. |
static Scheme |
Scheme.fromScheme(String aUrl) |
Determines the
Scheme from the given URL. |
static Scheme |
Scheme.valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Scheme[] |
Scheme.values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
Copyright © 2018. All rights reserved.