All Classes

Class Description
AckTimeout
The AckTimeout defines values used inside a Transmit/Acknowledge (ARQ) processing control flow.
Annotator
Commonly used characters to be prefixed to annotations' names to distinguish them form element names and the like.
AnsiEscapeCode
This enumeration contains ANSI Escape-Codes for modifying the appearance of console output to ANSI enabled terminals.
AsciiColorPalette
An enumeration for text palette definitions to make it easy working with such default palettes.
Binary
Some values regarding binary numbers.
BitMask
The Enum BitMask.
BooleanLiterals
Some values's literal (String) representation useful when parsing or evaluating texts.
CharSet
Commonly used char sets.
CommandArgPrefix
Commonly used prefixes needful for analyzing, parsing or truncating command line arguments and so on.
CommandArgPrefixes
This enumeration groups CommandArgPrefix by platform.
ConsoleDimension
The Enum ConsoleDimension.
DaemonLoopSleepTime
The DaemonLoopSleepTime defined values used inside a control flow.
DataArrayLocator
Provides an accessor for a data locators property (array of URLs and InputStreams).
DataArrayLocator.DataLocatorsBuilder<B extends DataArrayLocator.DataLocatorsBuilder<B>>
Provides a builder for a data locators property.
DataArrayLocator.DataLocatorsMutator
Provides a mutator for a data locators property.
DataArrayLocator.DataLocatorsProperty
Provides a property (getter / setter) for a data locators property (width and height).
DataLocator
Provides an accessor for a data locator property (URL and InputStream).
DataLocator.DataLocatorBuilder<B extends DataLocator.DataLocatorBuilder<B>>
Provides a builder for a data locator property.
DataLocator.DataLocatorMutator
Provides a mutator for a data locator property.
DataLocator.DataLocatorProperty
Provides a property (getter / setter) for a data locator property (width and height).
Delimiter
Commonly used characters when working with separated values or properties and the like making use of text separator characters .
Delimiters
The Delimiters groups Delimiter values belonging somehow together or sharing a similar semantics.
Encoding
The Encoding define values representing an encoding which are to be passed as argument to according methods.
EndOfLine
Commonly used characters for EOL markers in texts.
EnvironmentVariable
EnvironmentVariable for retrieving some common environment variables with ease.
Field
The Field are useful when working with fields defined for external systems such as databases or when working with tables or Map instances.
FilenameExtension
The FilenameExtension define values useful when working with files or a file-system.
Flag
A flag can be on or off.
Folder
The Folder define values useful when working with files or a file-system.
Folders
The Folders define values useful when working with folders on a file-system.
IoBlockSize
The IoBlockSize defined values used inside a control flow.
IoPollLoopTime
The IoPollLoopTime defined values used when polling data from I/O, e.g. the file system or via TCP/IP.
IoRetryCount
The IoRetryCount defined values used inside a control flow.
IoSleepLoopTime
The IoSleepLoopTime defined values used inside a control flow.
IoTimeout
The IoTimeout defines values used inside a IO processing control flow.
LatencySleepTime
The LatencySleepTime defined values used inside a control flow.
License
Some licensing and copyright information as String constants.
Literal
Some values's literal (String) representation useful when parsing or evaluating texts.
Literals
Some values's literal (String) representation useful when parsing or evaluating texts.
LoopExtensionTime
The LoopExtensionTime defined values used inside a control flow.
MarshalParameter
MarshalParameter defines common parameters (parameter is considered the key of a key/value pair) of a given semantics for the according property.
MoreText
Commonly used characters needful for analyzing, parsing or truncating texts.
PaddingChar
Commonly used characters needful for analyzing, parsing or truncating texts.
Port
The Enum Port.
Prefix
Commonly used prefixes needful for analyzing, parsing or truncating texts the like.
QuotationMark
Commonly used characters needful for analyzing, parsing or truncating texts.
Region
A text region has a beginning index being included by the region and an end index being excluded by the region and a resulting length.
RetryCount
The RetryCount defined values used inside a control flow.
RetryLoopCount
The RetryLoopCount defined values used inside a control flow.
ScheduleSleepTime
The ScheduleSleepTime defined values used inside a control flow.
Scheme
The Scheme define values useful when working with files or a file-system.
SleepLoopTime
The SleepLoopTime defined values used inside a control flow.
Suffix
Commonly used characters needful for analyzing, parsing or truncating texts.
SystemProperty
SystemProperty define values to be used at runtime.
Text
Commonly used text blocks in the code.
TextBorder
The Enum TextBorder.
Wildcard
Commonly used characters needful for analyzing, parsing or truncating texts.