JavaScript is disabled on your browser.
Description
Nested Class Summary
Enum Constant Summary
Method Summary
Enum Constant Details
NULL
SOH
STX
ETX
EOT
ENQ
ACK
BELL
DLE
NAK
SYN
CAN
EM
ESC
Method Details
values()
valueOf(String)
getCode()
getChar()
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.CharAccessor
org.refcodes.mixin.CharAccessor.CharBuilder<B>, org.refcodes.mixin.CharAccessor.CharMutator, org.refcodes.mixin.CharAccessor.CharProperty
Nested classes/interfaces inherited from interface org.refcodes.mixin.CodeAccessor
org.refcodes.mixin.CodeAccessor.CodeBuilder<T,B>, org.refcodes.mixin.CodeAccessor.CodeMutator<T>, org.refcodes.mixin.CodeAccessor.CodeProperty<T>
Enum Constant Summary
Enum Constants
ASCII(6) = <ACK>
"Acknowledgement"
ASCII(24) = <CAN>
"Cancel"
* ASCII(16) = <DLE>
Data Link Escape
ASCII(25) = <EN>
"End of Medium"
ASCII(5) = <ENQ>
"Enquiry"
ASCII(4) = <EOT>
"End of Transmission"
ASCII(27) = <ESC>
"Escape"
ASCII(3) = <ETX>
"End of Text"
ASCII(21) = <NAK>
"Negative Acknowledgement"
ASCII(1) = <SOH>
"Start of Heading"
ASCII(2) = <STX>
"Start of Text"
ASCII(22) = <SYN>
"Synchronous Idle"
Method Summary
All Methods Static Methods Instance Methods Concrete Methods
char
Returns the enum constant of this class with the specified name.
Returns an array containing the constants of this enum class, in
the order they are declared.
Methods inherited from class Enum
clone , compareTo , describeConstable , equals , finalize , getDeclaringClass , hashCode , name , ordinal , toString , valueOf