- All Implemented Interfaces:
Serializable,Comparable<CharSet>,java.lang.constant.Constable,org.refcodes.mixin.CharSetAccessor
public enum CharSet extends Enum<CharSet> implements org.refcodes.mixin.CharSetAccessor
Commonly used char sets.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>>Nested classes/interfaces inherited from interface org.refcodes.mixin.CharSetAccessor
org.refcodes.mixin.CharSetAccessor.CharSetBuilder<B extends org.refcodes.mixin.CharSetAccessor.CharSetBuilder<B>>, org.refcodes.mixin.CharSetAccessor.CharSetMutator, org.refcodes.mixin.CharSetAccessor.CharSetProperty -
Enum Constant Summary
Enum Constants Enum Constant Description ALPHABETICALPHANUMERICARABIC_BASE64ASCIIBASE64BASE64URLBINARYCLOSING_BRACESCharacters representing closing braces.ENCODED_AS_NUMBERNo prefixing zeros allowed when encoding a value to be stored by a (JSON) number variable.END_OF_LINEHEXADECIMALLINE_BREAK_MARKERSWhen formatting texts, those chars can be used to identify a possible suitable end of line (when seeking for a position to do a line-break).LOWER_CASENUMERICOPENING_BRACESCharacters representing opening braces.QUOTESREGEX_SPECIAL_CHARSSPACE_MARKERSWhen formatting texts, those chars can be used to identify a space between two words.UPPER_CASEWHITE_SPACES -
Method Summary
Modifier and Type Method Description char[]getCharSet()booleanhasChar(char aChar)Checks for char.static CharSetvalueOf(String name)Returns the enum constant of this type with the specified name.static CharSet[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
Enum Constant Details
-
ASCII
-
ALPHABETIC
-
UPPER_CASE
-
LOWER_CASE
-
ALPHANUMERIC
-
NUMERIC
-
ENCODED_AS_NUMBER
No prefixing zeros allowed when encoding a value to be stored by a (JSON) number variable. -
BINARY
-
HEXADECIMAL
-
BASE64
-
BASE64URL
-
ARABIC_BASE64
-
QUOTES
-
WHITE_SPACES
-
END_OF_LINE
-
LINE_BREAK_MARKERS
When formatting texts, those chars can be used to identify a possible suitable end of line (when seeking for a position to do a line-break). -
OPENING_BRACES
Characters representing opening braces. -
CLOSING_BRACES
Characters representing closing braces. -
SPACE_MARKERS
When formatting texts, those chars can be used to identify a space between two words. -
REGEX_SPECIAL_CHARS
-
-
Method Details
-
values
Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getCharSet
public char[] getCharSet()- Specified by:
getCharSetin interfaceorg.refcodes.mixin.CharSetAccessor
-
hasChar
public boolean hasChar(char aChar)Checks for char.- Parameters:
aChar- the char- Returns:
- true, if successful
-