Enum Class Encoding
- All Implemented Interfaces:
Serializable,Comparable<Encoding>,Constable,org.refcodes.mixin.CodeAccessor<String>
The
Encoding define values representing an encoding which are to be
passed as argument to according methods.-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>>Nested classes/interfaces inherited from interface org.refcodes.mixin.CodeAccessor
org.refcodes.mixin.CodeAccessor.CodeBuilder<T,B extends org.refcodes.mixin.CodeAccessor.CodeBuilder<T, B>>, org.refcodes.mixin.CodeAccessor.CodeMutator<T>, org.refcodes.mixin.CodeAccessor.CodeProperty<T> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionCP1252 (Code Page 1252) is a character encoding used in Microsoft Windows for Western European languages, such as English, French, German, Spanish, Portuguese, Italian, and others.This encoding is useful when having to ensure a 1-to-1 mapping between bytes and characters.MD5 hash encoding.Encoding identifying UTF-8 when working withStringobjects. -
Method Summary
Modifier and TypeMethodDescriptiongetCode()booleanisEncoding(String aEncoding) Determines weather the given string representation represents the accordingEncoding.static EncodingReturns the enum constant of this class with the specified name.static Encoding[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
UTF_8
-
ISO_8859_1
This encoding is useful when having to ensure a 1-to-1 mapping between bytes and characters. -
CP1252
CP1252 (Code Page 1252) is a character encoding used in Microsoft Windows for Western European languages, such as English, French, German, Spanish, Portuguese, Italian, and others. CP1252 is not as widely used as it once was, as Unicode has become the dominant character encoding for modern software and the web. However, it is still important for maintaining compatibility with legacy systems and applications that use this encoding. -
MD5
MD5 hash encoding.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getCode
-
isEncoding
-