- All Implemented Interfaces:
Serializable,Comparable<Encoding>,java.lang.constant.Constable,org.refcodes.mixin.CodeAccessor<String>
public enum Encoding extends Enum<Encoding> implements org.refcodes.mixin.CodeAccessor<String>
The
Encoding define values representing an encoding which are to be
passed as argument to according methods.-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>>Nested classes/interfaces inherited from interface org.refcodes.mixin.CodeAccessor
org.refcodes.mixin.CodeAccessor.CodeBuilder<T extends Object,B extends org.refcodes.mixin.CodeAccessor.CodeBuilder<T,B>>, org.refcodes.mixin.CodeAccessor.CodeMutator<T extends Object>, org.refcodes.mixin.CodeAccessor.CodeProperty<T extends Object> -
Enum Constant Summary
Enum Constants Enum Constant Description ISO_8859_1This encoding is especially useful when having to ensure a 1-to-1 mapping between bytes and characters.MD5MD5 hash encoding.UTF_8Encoding identifying UTF-8 when working withStringobjects. -
Method Summary
-
Enum Constant Details
-
UTF_8
Encoding identifying UTF-8 when working withStringobjects. -
ISO_8859_1
This encoding is especially useful when having to ensure a 1-to-1 mapping between bytes and characters. -
MD5
MD5 hash encoding.
-
-
Method Details
-
values
Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getCode
- Specified by:
getCodein interfaceorg.refcodes.mixin.CodeAccessor<String>
-