JavaScript is disabled on your browser.
Description
Nested Class Summary
Enum Constant Summary
Method Summary
Enum Constant Details
CARRIAGE_RETURN
LINE_FEED
Method Details
values()
valueOf(String)
getChar()
isEndOfLine(char)
toChars()
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.CharAccessor
org.refcodes.mixin.CharAccessor.CharBuilder<B>, org.refcodes.mixin.CharAccessor.CharMutator, org.refcodes.mixin.CharAccessor.CharProperty
Enum Constant Summary
Enum Constants
Method Summary
All Methods Static Methods Instance Methods Concrete Methods
char
static boolean
Tests if the given potential EOL character is contained in the
EndOfLine enumeration.
static char[]
Returns an array of the characters representing the EOL characters in
this grouping enumeration.
Returns the enum constant of this class with the specified name.
Returns an array containing the constants of this enum class, in
the order they are declared.
Methods inherited from class Enum
clone , compareTo , describeConstable , equals , finalize , getDeclaringClass , hashCode , name , ordinal , toString , valueOf