- All Implemented Interfaces:
Serializable,Comparable<EndOfLine>,Constable,org.refcodes.mixin.CharAccessor
Commonly used characters for EOL markers in texts.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>>Nested classes/interfaces inherited from interface org.refcodes.mixin.CharAccessor
org.refcodes.mixin.CharAccessor.CharBuilder<B extends org.refcodes.mixin.CharAccessor.CharBuilder<B>>, org.refcodes.mixin.CharAccessor.CharMutator, org.refcodes.mixin.CharAccessor.CharProperty -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionchargetChar()static booleanisEndOfLine(char aEndOfLine) Tests if the given potential EOL character is contained in theEndOfLineenumeration.static char[]toChars()Returns an array of the characters representing the EOL characters in this grouping enumeration.static EndOfLineReturns the enum constant of this class with the specified name.static EndOfLine[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
CARRIAGE_RETURN
-
LINE_FEED
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getChar
public char getChar()- Specified by:
getCharin interfaceorg.refcodes.mixin.CharAccessor
-
isEndOfLine
public static boolean isEndOfLine(char aEndOfLine) Tests if the given potential EOL character is contained in theEndOfLineenumeration.- Parameters:
aEndOfLine- the potential EOL character- Returns:
- True, if the given EOL character is contained in the
EndOfLineenumeration, else false.
-
toChars
public static char[] toChars()Returns an array of the characters representing the EOL characters in this grouping enumeration.- Returns:
- The character array of the herein contained EOL characters.
-