- java.lang.Object
-
- java.lang.Enum<ExitCode>
-
- org.refcodes.data.ExitCode
-
- All Implemented Interfaces:
Serializable,Comparable<ExitCode>,org.refcodes.mixin.StatusCodeAccessor<Integer>
public enum ExitCode extends Enum<ExitCode> implements org.refcodes.mixin.StatusCodeAccessor<Integer>
Some default exit codes defined for CLI applications.- Author:
- steiner
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.StatusCodeAccessor
org.refcodes.mixin.StatusCodeAccessor.StatusCodeBuilder<SC extends Object,B extends org.refcodes.mixin.StatusCodeAccessor.StatusCodeBuilder<SC,B>>, org.refcodes.mixin.StatusCodeAccessor.StatusCodeMutator<SC extends Object>, org.refcodes.mixin.StatusCodeAccessor.StatusCodeProperty<SC extends Object>
-
-
Enum Constant Summary
Enum Constants Enum Constant Description CANNOT_EXECUTECommand invoked cannot execute, e.g. permission problem.CATCHALLCONTROL_CScript terminated by Control-C Ctl-C Control-CMISUSEMissing keyword or command, or permission problem.NOT_FOUNDPossible problem with $PATH or a typo.SUCCESS
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description IntegergetStatusCode()Gets the status code.static ExitCodevalueOf(String name)Returns the enum constant of this type with the specified name.static ExitCode[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
SUCCESS
public static final ExitCode SUCCESS
-
CATCHALL
public static final ExitCode CATCHALL
-
MISUSE
public static final ExitCode MISUSE
Missing keyword or command, or permission problem.
-
CANNOT_EXECUTE
public static final ExitCode CANNOT_EXECUTE
Command invoked cannot execute, e.g. permission problem.
-
NOT_FOUND
public static final ExitCode NOT_FOUND
Possible problem with $PATH or a typo.
-
CONTROL_C
public static final ExitCode CONTROL_C
Script terminated by Control-C Ctl-C Control-C
-
-
Method Detail
-
values
public static ExitCode[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (ExitCode c : ExitCode.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static ExitCode valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
-