Enum LoopExtensionTime

java.lang.Object
java.lang.Enum<LoopExtensionTime>
org.refcodes.data.LoopExtensionTime
All Implemented Interfaces:
Serializable, Comparable<LoopExtensionTime>, java.lang.constant.Constable, org.refcodes.mixin.TimeInMsAccessor

public enum LoopExtensionTime
extends Enum<LoopExtensionTime>
implements org.refcodes.mixin.TimeInMsAccessor
The LoopExtensionTime defined values used inside a control flow.
  • Nested Class Summary

    Nested classes/interfaces inherited from class java.lang.Enum

    Enum.EnumDesc<E extends Enum<E>>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.TimeInMsAccessor

    org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B extends org.refcodes.mixin.TimeInMsAccessor.TimeInMsBuilder<B>>, org.refcodes.mixin.TimeInMsAccessor.TimeInMsMutator, org.refcodes.mixin.TimeInMsAccessor.TimeInMsProperty
  • Enum Constant Summary

    Enum Constants
    Enum Constant Description
    MAX
    A retry is being extended for each retry by an exponential delay extension time (when > 0): long theDelay((long) ( Math.pow(4, theRetries++ ) * EXTENSION_TIME ))), See also http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdf
    MIN
    A retry is being extended for each retry by an exponential delay extension time (when > 0): long theDelay((long) ( Math.pow(4, theRetries++ ) * EXTENSION_TIME ))), Also see http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdf
    NORM
    A retry is being extended for each retry by an exponential delay extension time (when > 0): long theDelay((long) ( Math.pow(4, theRetries++ ) * EXTENSION_TIME ))), Also see http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdf
  • Method Summary

    Modifier and Type Method Description
    int getTimeInMs()
    static LoopExtensionTime valueOf​(String name)
    Returns the enum constant of this type with the specified name.
    static LoopExtensionTime[] values()
    Returns an array containing the constants of this enum type, in the order they are declared.

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait
  • Enum Constant Details

    • MIN

      public static final LoopExtensionTime MIN
      A retry is being extended for each retry by an exponential delay extension time (when > 0): long theDelay((long) ( Math.pow(4, theRetries++ ) * EXTENSION_TIME ))), Also see http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdf
    • NORM

      public static final LoopExtensionTime NORM
      A retry is being extended for each retry by an exponential delay extension time (when > 0): long theDelay((long) ( Math.pow(4, theRetries++ ) * EXTENSION_TIME ))), Also see http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdf
    • MAX

      public static final LoopExtensionTime MAX
      A retry is being extended for each retry by an exponential delay extension time (when > 0): long theDelay((long) ( Math.pow(4, theRetries++ ) * EXTENSION_TIME ))), See also http://awsdocs.s3.amazonaws.com/SDB/latest/sdb-dg.pdf
  • Method Details

    • values

      public static LoopExtensionTime[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static LoopExtensionTime valueOf​(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • getTimeInMs

      public int getTimeInMs()
      Specified by:
      getTimeInMs in interface org.refcodes.mixin.TimeInMsAccessor