Enum Port

java.lang.Object
java.lang.Enum<Port>
org.refcodes.data.Port
All Implemented Interfaces:
Serializable, Comparable<Port>, java.lang.constant.Constable, org.refcodes.mixin.PortAccessor

public enum Port
extends Enum<Port>
implements org.refcodes.mixin.PortAccessor
The Enum Port.
  • Nested Class Summary

    Nested classes/interfaces inherited from class java.lang.Enum

    Enum.EnumDesc<E extends Enum<E>>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.PortAccessor

    org.refcodes.mixin.PortAccessor.PortBuilder<B extends org.refcodes.mixin.PortAccessor.PortBuilder<B>>, org.refcodes.mixin.PortAccessor.PortMutator, org.refcodes.mixin.PortAccessor.PortProperty
  • Enum Constant Summary

    Enum Constants
    Enum Constant Description
    DNS
    Domain Name System (DNS) service:.
    FTP
    File Transfer Protocol (FTP):.
    HTTP
    Hypertext Transfer Protocol (HTTP) used in the World Wide Web:.
    HTTP_ALTERNATE
    HTTP alternate (http_alt).
    HTTPS
    HTTP Secure (HTTPS):.
    IMAP
    Internet Message Access Protocol (IMAP):.
    IRC
    Internet Relay Chat (IRC):.
    NNTP
    Network News Transfer Protocol (NNTP):.
    NTP
    Network Time Protocol (NTP):.
    POP3
    Post Office Protocol (POP3):.
    REFCODES
    REFCODES.ORG:
    SMTP
    Simple Mail Transfer Protocol (SMTP):.
    SNMP
    Simple Network Management Protocol (SNMP):.
    SSH
    Secure Shell (SSH):.
    TELNET
    Telnet remote login service:.
  • Method Summary

    Modifier and Type Method Description
    int getPort()
    Gets the value.
    static Port valueOf​(String name)
    Returns the enum constant of this type with the specified name.
    static Port[] values()
    Returns an array containing the constants of this enum type, in the order they are declared.

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait
  • Enum Constant Details

    • FTP

      public static final Port FTP
      File Transfer Protocol (FTP):.
    • SSH

      public static final Port SSH
      Secure Shell (SSH):.
    • TELNET

      public static final Port TELNET
      Telnet remote login service:.
    • SMTP

      public static final Port SMTP
      Simple Mail Transfer Protocol (SMTP):.
    • DNS

      public static final Port DNS
      Domain Name System (DNS) service:.
    • HTTP

      public static final Port HTTP
      Hypertext Transfer Protocol (HTTP) used in the World Wide Web:.
    • POP3

      public static final Port POP3
      Post Office Protocol (POP3):.
    • NNTP

      public static final Port NNTP
      Network News Transfer Protocol (NNTP):.
    • NTP

      public static final Port NTP
      Network Time Protocol (NTP):.
    • IMAP

      public static final Port IMAP
      Internet Message Access Protocol (IMAP):.
    • SNMP

      public static final Port SNMP
      Simple Network Management Protocol (SNMP):.
    • IRC

      public static final Port IRC
      Internet Relay Chat (IRC):.
    • HTTPS

      public static final Port HTTPS
      HTTP Secure (HTTPS):.
    • REFCODES

      public static final Port REFCODES
      REFCODES.ORG:
    • HTTP_ALTERNATE

      public static final Port HTTP_ALTERNATE
      HTTP alternate (http_alt).
  • Method Details

    • values

      public static Port[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static Port valueOf​(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • getPort

      public int getPort()
      Gets the value.
      Specified by:
      getPort in interface org.refcodes.mixin.PortAccessor
      Returns:
      the value