- All Implemented Interfaces:
Serializable,Comparable<Port>,java.lang.constant.Constable,org.refcodes.mixin.PortAccessor
public enum Port extends Enum<Port> implements org.refcodes.mixin.PortAccessor
The Enum Port.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>>Nested classes/interfaces inherited from interface org.refcodes.mixin.PortAccessor
org.refcodes.mixin.PortAccessor.PortBuilder<B extends org.refcodes.mixin.PortAccessor.PortBuilder<B>>, org.refcodes.mixin.PortAccessor.PortMutator, org.refcodes.mixin.PortAccessor.PortProperty -
Enum Constant Summary
Enum Constants Enum Constant Description DNSDomain Name System (DNS) service:.FTPFile Transfer Protocol (FTP):.HTTPHypertext Transfer Protocol (HTTP) used in the World Wide Web:.HTTP_ALTERNATEHTTP alternate (http_alt).HTTPSHTTP Secure (HTTPS):.IMAPInternet Message Access Protocol (IMAP):.IRCInternet Relay Chat (IRC):.NNTPNetwork News Transfer Protocol (NNTP):.NTPNetwork Time Protocol (NTP):.POP3Post Office Protocol (POP3):.REFCODESREFCODES.ORG:SMTPSimple Mail Transfer Protocol (SMTP):.SNMPSimple Network Management Protocol (SNMP):.SSHSecure Shell (SSH):.TELNETTelnet remote login service:. -
Method Summary
-
Enum Constant Details
-
FTP
File Transfer Protocol (FTP):. -
SSH
Secure Shell (SSH):. -
TELNET
Telnet remote login service:. -
SMTP
Simple Mail Transfer Protocol (SMTP):. -
DNS
Domain Name System (DNS) service:. -
HTTP
Hypertext Transfer Protocol (HTTP) used in the World Wide Web:. -
POP3
Post Office Protocol (POP3):. -
NNTP
Network News Transfer Protocol (NNTP):. -
NTP
Network Time Protocol (NTP):. -
IMAP
Internet Message Access Protocol (IMAP):. -
SNMP
Simple Network Management Protocol (SNMP):. -
IRC
Internet Relay Chat (IRC):. -
HTTPS
HTTP Secure (HTTPS):. -
REFCODES
REFCODES.ORG: -
HTTP_ALTERNATE
HTTP alternate (http_alt).
-
-
Method Details
-
values
Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getPort
public int getPort()Gets the value.- Specified by:
getPortin interfaceorg.refcodes.mixin.PortAccessor- Returns:
- the value
-