Class Region

java.lang.Object
org.refcodes.data.Region

public class Region extends Object
A text region has a beginning index being included by the region and an end index being excluded by the region and a resulting length.