Enum Suffix

java.lang.Object
java.lang.Enum<Suffix>
org.refcodes.data.Suffix
All Implemented Interfaces:
Serializable, Comparable<Suffix>, java.lang.constant.Constable, org.refcodes.mixin.SuffixAccessor

public enum Suffix
extends Enum<Suffix>
implements org.refcodes.mixin.SuffixAccessor
Commonly used characters needful for analyzing, parsing or truncating texts.
  • Nested Class Summary

    Nested classes/interfaces inherited from class java.lang.Enum

    Enum.EnumDesc<E extends Enum<E>>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.SuffixAccessor

    org.refcodes.mixin.SuffixAccessor.SuffixBuilder<B extends org.refcodes.mixin.SuffixAccessor.SuffixBuilder<B>>, org.refcodes.mixin.SuffixAccessor.SuffixMutator, org.refcodes.mixin.SuffixAccessor.SuffixProperty
  • Enum Constant Summary

    Enum Constants
    Enum Constant Description
    PROTOCOL  
  • Method Summary

    Modifier and Type Method Description
    String getSuffix()
    static Suffix valueOf​(String name)
    Returns the enum constant of this type with the specified name.
    static Suffix[] values()
    Returns an array containing the constants of this enum type, in the order they are declared.

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait
  • Enum Constant Details

    • PROTOCOL

      public static final Suffix PROTOCOL
  • Method Details

    • values

      public static Suffix[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static Suffix valueOf​(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • getSuffix

      public String getSuffix()
      Specified by:
      getSuffix in interface org.refcodes.mixin.SuffixAccessor