- All Implemented Interfaces:
Serializable,Comparable<SystemProperty>,java.lang.constant.Constable,org.refcodes.mixin.KeyAccessor<String>,org.refcodes.mixin.ValueAccessor<String>,org.refcodes.mixin.ValueAccessor.ValueMutator<String>,org.refcodes.mixin.ValueAccessor.ValueProperty<String>
public enum SystemProperty extends Enum<SystemProperty> implements org.refcodes.mixin.KeyAccessor<String>, org.refcodes.mixin.ValueAccessor.ValueProperty<String>
SystemProperty define values to be used at runtime. Them are passed
to a JVM by prefixing a "-D" to the actual "property=value" pair.-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>>Nested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor
org.refcodes.mixin.KeyAccessor.KeyBuilder<K extends Object,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K extends Object>, org.refcodes.mixin.KeyAccessor.KeyProperty<K extends Object>Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Enum Constant Summary
Enum Constants Enum Constant Description CONFIG_DIRPass as JVM argument via "-Dconfig.dir=path_to_your_config_dir" (where path_to_your_config_dir stands for the path to the directory where you placed configuration files such as the "runtimelogger.ini" file).CONSOLE_ANSIPass as JVM argument via-Dconsole.ansi=<true|false>where "true" or "false" forces ANSI to be used / not used by REFCODES.ORG artifacts, no matter what capabilities were detected for the hosting terminal.CONSOLE_HEIGHTPass as JVM argument via "-Dconsole.height=n" (where n stands for the number of lines).CONSOLE_LINE_BREAKThe console's line-break property.CONSOLE_WIDTHPass as JVM argument via "-Dconsole.width=n" (where n stands for the number of chars per row).FILE_SEPARATORThe OS specific file separator is retrieved by this system property.HOST_SEEDSystem property "host.seed" for the Host-Seed for host-related IDs.HTTP_NON_PROXY_HOSTSNo-Proxy settings for theHTTP_PROXY_HOST(HTTP_PROXY_PORT) settings in a comma separated list ("localhost,127.0.0.0/8,127.0.1.1,127.0.1.1*,...")HTTP_PROXY_HOSTHTTP-Proxy host without a port ("http://my.company.org")HTTP_PROXY_PORTHTTP-Proxy port ("3128")HTTPS_NON_PROXY_HOSTSNo-Proxy settings for theHTTPS_PROXY_HOST(HTTPS_PROXY_PORT) settings in a comma separated list ("localhost,127.0.0.0/8,127.0.1.1,127.0.1.1*,...")HTTPS_PROXY_HOSTHTTPS-Proxy host without a port ("http://my.company.org")HTTPS_PROXY_PORTHTTP-Proxy port ("3128")JAVA_AWT_HEADLESSTo set up headless mode, set the appropriate system property ("https://www.oracle.com/technetwork/articles/javase/headless-136834.html").KEY_STORE_FILELocation of the Java keystore file containing an application process's own certificate and private key.KEY_STORE_PASSWORDPassword to access the private key from the keystore file specified byKEY_STORE_FILE.KEY_STORE_TYPEFor Java keystore file format, this property has the value "jks" (or "JKS").LAUNCHER_DIRSpecifies the path to your application's launcher dir, e.g. the place where your JAR resides in.LINE_SEPARATORSequence used by operating system to separate lines in text files.LOGGER_LAYOUTPass as JVM argument via "-Dlogger.layout=<layout>" (where<layout>stands for the chosen layout for the REFCODES.ORG logger artifacts.).LOGGER_STYLEPass as JVM argument via "-Dlogger.style=<style>" (where<style>stands for the chosen logger-style for the REFCODES.ORG logger artifacts.).OPERATING_SYSTEM_NAMEOperating system name.OS_ARCHProcessor architecture on some systems (e.g.PROCESS_IDAt least set on Ubuntu-Linux:.SOCKS_PROXY_HOSTSOCKS-Proxy host without a port ("http://my.company.org")SOCKS_PROXY_PORTSOCKS-Proxy port ("3128")TEMP_DIRThe OS specific temp folder path.TRUST_STORE_FILELocation of the Java keystore file containing the collection of CA certificates trusted by this application process (trust store).TRUST_STORE_PASSWORDPassword to unlock the keystore file (store password) specified byTRUST_STORE_FILE.TRUST_STORE_TYPEFor Java keystore file format, this property has the value "jks" (or "JKS").USER_DIRSystem variable holding the user's current working directory.USER_HOMESystem variable holding the user's home folder path.USER_NAMESystem variable holding the user's login name. -
Method Summary
Modifier and Type Method Description StringgetKey()StringgetValue()voidsetValue(String aValue)static SystemPropertyvalueOf(String name)Returns the enum constant of this type with the specified name.static SystemProperty[]values()Returns an array containing the constants of this enum type, in the order they are declared.Methods inherited from class java.lang.Enum
clone, compareTo, describeConstable, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOfMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOrMethods inherited from interface org.refcodes.mixin.ValueAccessor.ValueProperty
letValue
-
Enum Constant Details
-
JAVA_AWT_HEADLESS
To set up headless mode, set the appropriate system property ("https://www.oracle.com/technetwork/articles/javase/headless-136834.html"). -
HTTP_PROXY_HOST
HTTP-Proxy host without a port ("http://my.company.org") -
HTTP_PROXY_PORT
HTTP-Proxy port ("3128") -
HTTPS_PROXY_HOST
HTTPS-Proxy host without a port ("http://my.company.org") -
HTTPS_PROXY_PORT
HTTP-Proxy port ("3128") -
SOCKS_PROXY_HOST
SOCKS-Proxy host without a port ("http://my.company.org") -
SOCKS_PROXY_PORT
SOCKS-Proxy port ("3128") -
HOST_SEED
System property "host.seed" for the Host-Seed for host-related IDs. -
HTTP_NON_PROXY_HOSTS
No-Proxy settings for theHTTP_PROXY_HOST(HTTP_PROXY_PORT) settings in a comma separated list ("localhost,127.0.0.0/8,127.0.1.1,127.0.1.1*,...") -
HTTPS_NON_PROXY_HOSTS
No-Proxy settings for theHTTPS_PROXY_HOST(HTTPS_PROXY_PORT) settings in a comma separated list ("localhost,127.0.0.0/8,127.0.1.1,127.0.1.1*,...") -
OS_ARCH
Processor architecture on some systems (e.g. "AMD64"). -
CONFIG_DIR
Pass as JVM argument via "-Dconfig.dir=path_to_your_config_dir" (where path_to_your_config_dir stands for the path to the directory where you placed configuration files such as the "runtimelogger.ini" file). -
FILE_SEPARATOR
The OS specific file separator is retrieved by this system property. ATTENTION: System properties are to be retrieved viaSystem.getProperty(String). -
TEMP_DIR
The OS specific temp folder path. -
PROCESS_ID
At least set on Ubuntu-Linux:. -
LINE_SEPARATOR
Sequence used by operating system to separate lines in text files. -
OPERATING_SYSTEM_NAME
Operating system name. -
LAUNCHER_DIR
Specifies the path to your application's launcher dir, e.g. the place where your JAR resides in. Pass as JVM argument via "-Dlauncher.dir=/path/to/launcher/dir". -
CONSOLE_HEIGHT
Pass as JVM argument via "-Dconsole.height=n" (where n stands for the number of lines). -
CONSOLE_WIDTH
Pass as JVM argument via "-Dconsole.width=n" (where n stands for the number of chars per row). -
CONSOLE_ANSI
Pass as JVM argument via-Dconsole.ansi=<true|false>where "true" or "false" forces ANSI to be used / not used by REFCODES.ORG artifacts, no matter what capabilities were detected for the hosting terminal. -
CONSOLE_LINE_BREAK
The console's line-break property. Used to override any default line breaks for the REFCODES-ORG artifacts. -
LOGGER_LAYOUT
Pass as JVM argument via "-Dlogger.layout=<layout>" (where<layout>stands for the chosen layout for the REFCODES.ORG logger artifacts.). -
LOGGER_STYLE
Pass as JVM argument via "-Dlogger.style=<style>" (where<style>stands for the chosen logger-style for the REFCODES.ORG logger artifacts.). -
USER_HOME
System variable holding the user's home folder path. -
USER_NAME
System variable holding the user's login name. -
USER_DIR
System variable holding the user's current working directory. -
KEY_STORE_FILE
Location of the Java keystore file containing an application process's own certificate and private key. -
KEY_STORE_PASSWORD
Password to access the private key from the keystore file specified byKEY_STORE_FILE. -
KEY_STORE_TYPE
For Java keystore file format, this property has the value "jks" (or "JKS"). Its default value is already "jks". -
TRUST_STORE_FILE
Location of the Java keystore file containing the collection of CA certificates trusted by this application process (trust store). -
TRUST_STORE_PASSWORD
Password to unlock the keystore file (store password) specified byTRUST_STORE_FILE. -
TRUST_STORE_TYPE
For Java keystore file format, this property has the value "jks" (or "JKS"). Its default value is already "jks".
-
-
Method Details
-
values
Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getKey
- Specified by:
getKeyin interfaceorg.refcodes.mixin.KeyAccessor<String>
-
getValue
- Specified by:
getValuein interfaceorg.refcodes.mixin.ValueAccessor<String>
-
setValue
- Specified by:
setValuein interfaceorg.refcodes.mixin.ValueAccessor.ValueMutator<String>
-