Uses of Enum
org.refcodes.data.AckTimeout
-
Uses of AckTimeout in org.refcodes.data
Methods in org.refcodes.data that return AckTimeoutModifier and TypeMethodDescriptionstatic AckTimeoutReturns the enum constant of this type with the specified name.static AckTimeout[]AckTimeout.values()Returns an array containing the constants of this enum type, in the order they are declared.