Uses of Class
org.refcodes.data.AckTimeout
-
-
Uses of AckTimeout in org.refcodes.data
Methods in org.refcodes.data that return AckTimeout Modifier and Type Method Description static AckTimeoutAckTimeout. valueOf(String name)Returns the enum constant of this type with the specified name.static AckTimeout[]AckTimeout. values()Returns an array containing the constants of this enum type, in the order they are declared.
-