Uses of Enum Class
org.refcodes.data.AnsiEscapeCode
-
Uses of AnsiEscapeCode in org.refcodes.data
Methods in org.refcodes.data that return AnsiEscapeCodeModifier and TypeMethodDescriptionstatic AnsiEscapeCodeReturns the enum constant of this class with the specified name.static AnsiEscapeCode[]AnsiEscapeCode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.data with parameters of type AnsiEscapeCodeModifier and TypeMethodDescriptionstatic StringAnsiEscapeCode.toEscapeSequence(AnsiEscapeCode... aAnsiEscapeCodes) Basic functionality to create an ANSI Escape-Code sequence from the providedAnsiEscapeCodeelements directly printable toSystem.out.