Uses of Enum Class
org.refcodes.data.ArgsPrefix
-
Uses of ArgsPrefix in org.refcodes.data
Methods in org.refcodes.data that return ArgsPrefixModifier and TypeMethodDescriptionArgsPrefixes.getCommandArgPrefixes()Returns the relatedArgsPrefixelements.static ArgsPrefixReturns the enum constant of this class with the specified name.static ArgsPrefix[]ArgsPrefix.values()Returns an array containing the constants of this enum class, in the order they are declared.