Uses of Enum Class
org.refcodes.data.ArgsPrefixes
-
Uses of ArgsPrefixes in org.refcodes.data
Methods in org.refcodes.data that return ArgsPrefixesModifier and TypeMethodDescriptionstatic ArgsPrefixesReturns the enum constant of this class with the specified name.static ArgsPrefixes[]ArgsPrefixes.values()Returns an array containing the constants of this enum class, in the order they are declared.