Uses of Enum Class
org.refcodes.data.BooleanLiterals
-
Uses of BooleanLiterals in org.refcodes.data
Methods in org.refcodes.data that return BooleanLiteralsModifier and TypeMethodDescriptionstatic BooleanLiteralsReturns the enum constant of this class with the specified name.static BooleanLiterals[]BooleanLiterals.values()Returns an array containing the constants of this enum class, in the order they are declared.