Uses of Enum Class
org.refcodes.data.CharSet

  • Uses of CharSet in org.refcodes.data

    Methods in org.refcodes.data that return CharSet
    Modifier and Type
    Method
    Description
    static CharSet
    CharSet.toCharset(String aCharsetName)
    Returns the charset which's name matches the provided name, ignoring the case and the underscore ("_").
    static CharSet
    CharSet.valueOf(String name)
    Returns the enum constant of this class with the specified name.
    static CharSet[]
    CharSet.values()
    Returns an array containing the constants of this enum class, in the order they are declared.