Uses of Enum Class
org.refcodes.data.CharSet
-
Uses of CharSet in org.refcodes.data
Methods in org.refcodes.data that return CharSetModifier and TypeMethodDescriptionstatic CharSetReturns the charset which's name matches the provided name, ignoring the case and the underscore ("_").static CharSetReturns the enum constant of this class with the specified name.static CharSet[]CharSet.values()Returns an array containing the constants of this enum class, in the order they are declared.