Uses of Enum
org.refcodes.data.CommandArgPrefix
-
Uses of CommandArgPrefix in org.refcodes.data
Methods in org.refcodes.data that return CommandArgPrefixModifier and TypeMethodDescriptionCommandArgPrefixes.getCommandArgPrefixes()Returns the relatedCommandArgPrefixelements.static CommandArgPrefixReturns the enum constant of this type with the specified name.static CommandArgPrefix[]CommandArgPrefix.values()Returns an array containing the constants of this enum type, in the order they are declared.