Uses of Enum
org.refcodes.data.CommandArgPrefixes
-
Uses of CommandArgPrefixes in org.refcodes.data
Methods in org.refcodes.data that return CommandArgPrefixesModifier and TypeMethodDescriptionstatic CommandArgPrefixesReturns the enum constant of this type with the specified name.static CommandArgPrefixes[]CommandArgPrefixes.values()Returns an array containing the constants of this enum type, in the order they are declared.