Uses of Enum Class
org.refcodes.data.ConsoleDimension
-
Uses of ConsoleDimension in org.refcodes.data
Methods in org.refcodes.data that return ConsoleDimensionModifier and TypeMethodDescriptionstatic ConsoleDimensionReturns the enum constant of this class with the specified name.static ConsoleDimension[]ConsoleDimension.values()Returns an array containing the constants of this enum class, in the order they are declared.