Uses of Enum
org.refcodes.data.DaemonLoopSleepTime
-
Uses of DaemonLoopSleepTime in org.refcodes.data
Methods in org.refcodes.data that return DaemonLoopSleepTimeModifier and TypeMethodDescriptionstatic DaemonLoopSleepTimeReturns the enum constant of this type with the specified name.static DaemonLoopSleepTime[]DaemonLoopSleepTime.values()Returns an array containing the constants of this enum type, in the order they are declared.