Uses of Enum Class
org.refcodes.data.Delimiter
-
Uses of Delimiter in org.refcodes.data
Methods in org.refcodes.data that return DelimiterModifier and TypeMethodDescriptionstatic DelimiterReturns the enum constant of this class with the specified name.static Delimiter[]Delimiter.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.data with parameters of type DelimiterModifier and TypeMethodDescriptionbooleanDelimiters.isDelimiter(Delimiter aDelimiter) Tests if the given delimiter is contained in theDelimitersdefinition.