Uses of Enum
org.refcodes.data.Delimiter
-
Uses of Delimiter in org.refcodes.data
Methods in org.refcodes.data that return DelimiterModifier and TypeMethodDescriptionstatic DelimiterReturns the enum constant of this type with the specified name.static Delimiter[]Delimiter.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.data with parameters of type DelimiterModifier and TypeMethodDescriptionbooleanDelimiters.isDelimiter(Delimiter aDelimiter) Tests if the given delimiter is contained in theDelimitersdefinition.