Uses of Enum
org.refcodes.data.Delimiters
-
Uses of Delimiters in org.refcodes.data
Methods in org.refcodes.data that return DelimitersModifier and TypeMethodDescriptionstatic DelimitersReturns the enum constant of this type with the specified name.static Delimiters[]Delimiters.values()Returns an array containing the constants of this enum type, in the order they are declared.