Uses of Class
org.refcodes.data.ExitCode
-
-
Uses of ExitCode in org.refcodes.data
Methods in org.refcodes.data that return ExitCode Modifier and Type Method Description static ExitCodeExitCode. valueOf(String name)Returns the enum constant of this type with the specified name.static ExitCode[]ExitCode. values()Returns an array containing the constants of this enum type, in the order they are declared.
-