Uses of Class
org.refcodes.data.Flag

  • Uses of Flag in org.refcodes.data

    Methods in org.refcodes.data that return Flag
    Modifier and Type Method Description
    static Flag Flag.valueOf​(String name)
    Returns the enum constant of this type with the specified name.
    static Flag[] Flag.values()
    Returns an array containing the constants of this enum type, in the order they are declared.