Uses of Class
org.refcodes.data.IoHeurisitcsTimeToLive
-
-
Uses of IoHeurisitcsTimeToLive in org.refcodes.data
Methods in org.refcodes.data that return IoHeurisitcsTimeToLive Modifier and Type Method Description static IoHeurisitcsTimeToLiveIoHeurisitcsTimeToLive. valueOf(String name)Returns the enum constant of this type with the specified name.static IoHeurisitcsTimeToLive[]IoHeurisitcsTimeToLive. values()Returns an array containing the constants of this enum type, in the order they are declared.
-