Uses of Enum
org.refcodes.data.IoPollLoopTime
-
Uses of IoPollLoopTime in org.refcodes.data
Methods in org.refcodes.data that return IoPollLoopTimeModifier and TypeMethodDescriptionstatic IoPollLoopTimeReturns the enum constant of this type with the specified name.static IoPollLoopTime[]IoPollLoopTime.values()Returns an array containing the constants of this enum type, in the order they are declared.