Uses of Enum
org.refcodes.data.IoReconnectLoopTime
-
Uses of IoReconnectLoopTime in org.refcodes.data
Methods in org.refcodes.data that return IoReconnectLoopTimeModifier and TypeMethodDescriptionstatic IoReconnectLoopTimeReturns the enum constant of this type with the specified name.static IoReconnectLoopTime[]IoReconnectLoopTime.values()Returns an array containing the constants of this enum type, in the order they are declared.