Uses of Class
org.refcodes.data.IoReconnectLoopTime
-
-
Uses of IoReconnectLoopTime in org.refcodes.data
Methods in org.refcodes.data that return IoReconnectLoopTime Modifier and Type Method Description static IoReconnectLoopTimeIoReconnectLoopTime. valueOf(String name)Returns the enum constant of this type with the specified name.static IoReconnectLoopTime[]IoReconnectLoopTime. values()Returns an array containing the constants of this enum type, in the order they are declared.
-