Uses of Enum
org.refcodes.data.IoRetryCount
-
Uses of IoRetryCount in org.refcodes.data
Methods in org.refcodes.data that return IoRetryCountModifier and TypeMethodDescriptionstatic IoRetryCountReturns the enum constant of this type with the specified name.static IoRetryCount[]IoRetryCount.values()Returns an array containing the constants of this enum type, in the order they are declared.