Uses of Enum
org.refcodes.data.IoSleepLoopTime
-
Uses of IoSleepLoopTime in org.refcodes.data
Methods in org.refcodes.data that return IoSleepLoopTimeModifier and TypeMethodDescriptionstatic IoSleepLoopTimeReturns the enum constant of this type with the specified name.static IoSleepLoopTime[]IoSleepLoopTime.values()Returns an array containing the constants of this enum type, in the order they are declared.