Uses of Class
org.refcodes.data.IoSleepLoopTime
-
Uses of IoSleepLoopTime in org.refcodes.data
Methods in org.refcodes.data that return IoSleepLoopTime Modifier and Type Method Description static IoSleepLoopTimeIoSleepLoopTime. valueOf(String name)Returns the enum constant of this type with the specified name.static IoSleepLoopTime[]IoSleepLoopTime. values()Returns an array containing the constants of this enum type, in the order they are declared.