Uses of Enum
org.refcodes.data.LatencySleepTime
-
Uses of LatencySleepTime in org.refcodes.data
Methods in org.refcodes.data that return LatencySleepTimeModifier and TypeMethodDescriptionstatic LatencySleepTimeReturns the enum constant of this type with the specified name.static LatencySleepTime[]LatencySleepTime.values()Returns an array containing the constants of this enum type, in the order they are declared.