Uses of Enum
org.refcodes.data.LoopExtensionTime
-
Uses of LoopExtensionTime in org.refcodes.data
Methods in org.refcodes.data that return LoopExtensionTimeModifier and TypeMethodDescriptionstatic LoopExtensionTimeReturns the enum constant of this type with the specified name.static LoopExtensionTime[]LoopExtensionTime.values()Returns an array containing the constants of this enum type, in the order they are declared.