Uses of Enum
org.refcodes.data.MarshalParameter
-
Uses of MarshalParameter in org.refcodes.data
Methods in org.refcodes.data that return MarshalParameterModifier and TypeMethodDescriptionstatic MarshalParameterReturns the enum constant of this type with the specified name.static MarshalParameter[]MarshalParameter.values()Returns an array containing the constants of this enum type, in the order they are declared.