Uses of Enum Class
org.refcodes.data.Prefix
-
Uses of Prefix in org.refcodes.data
Subclasses with type arguments of type Prefix in org.refcodes.dataModifier and TypeClassDescriptionenumCommonly used prefixes needful for analyzing, parsing or truncating texts the like.Methods in org.refcodes.data that return Prefix