Uses of Enum Class
org.refcodes.data.QuotationMark
-
Uses of QuotationMark in org.refcodes.data
Methods in org.refcodes.data that return QuotationMarkModifier and TypeMethodDescriptionstatic QuotationMarkReturns the enum constant of this class with the specified name.static QuotationMark[]QuotationMark.values()Returns an array containing the constants of this enum class, in the order they are declared.