Uses of Enum
org.refcodes.data.ScheduleSleepTime
-
Uses of ScheduleSleepTime in org.refcodes.data
Methods in org.refcodes.data that return ScheduleSleepTimeModifier and TypeMethodDescriptionstatic ScheduleSleepTimeReturns the enum constant of this type with the specified name.static ScheduleSleepTime[]ScheduleSleepTime.values()Returns an array containing the constants of this enum type, in the order they are declared.