Uses of Class
org.refcodes.data.SleepLoopTime
-
-
Uses of SleepLoopTime in org.refcodes.data
Methods in org.refcodes.data that return SleepLoopTime Modifier and Type Method Description static SleepLoopTimeSleepLoopTime. valueOf(String name)Returns the enum constant of this type with the specified name.static SleepLoopTime[]SleepLoopTime. values()Returns an array containing the constants of this enum type, in the order they are declared.
-