Uses of Enum Class
org.refcodes.data.Suffix
-
Uses of Suffix in org.refcodes.data
Subclasses with type arguments of type Suffix in org.refcodes.dataModifier and TypeClassDescriptionenumCommonly used characters needful for analyzing, parsing or truncating texts.Methods in org.refcodes.data that return Suffix