JavaScript is disabled on your browser.
Skip navigation links
Module
Package
Class
Use
Tree
Index
Help
SEARCH
Uses of Enum Class
org.refcodes.data.Suffix
Uses of
Suffix
in
org.refcodes.data
Methods in
org.refcodes.data
that return
Suffix
Modifier and Type
Method
Description
static
Suffix
Suffix.
valueOf
(
String
name)
Returns the enum constant of this class with the specified name.
static
Suffix
[]
Suffix.
values
()
Returns an array containing the constants of this enum class, in the order they are declared.