Uses of Class
org.refcodes.data.Text

  • Uses of Text in org.refcodes.data

    Methods in org.refcodes.data that return Text
    Modifier and Type Method Description
    static Text Text.valueOf​(String name)
    Returns the enum constant of this type with the specified name.
    static Text[] Text.values()
    Returns an array containing the constants of this enum type, in the order they are declared.