Uses of Enum
org.refcodes.data.TextBorder
-
Uses of TextBorder in org.refcodes.data
Methods in org.refcodes.data that return TextBorderModifier and TypeMethodDescriptionstatic TextBorderReturns the enum constant of this type with the specified name.static TextBorder[]TextBorder.values()Returns an array containing the constants of this enum type, in the order they are declared.