Module org.refcodes.data
Package org.refcodes.data
-
Interface Summary Interface Description DataArrayLocator Provides an accessor for a data locators property (array ofURLs andInputStreams).DataArrayLocator.DataLocatorsBuilder<B extends DataArrayLocator.DataLocatorsBuilder<B>> Provides a builder for a data locators property.DataArrayLocator.DataLocatorsMutator Provides a mutator for a data locators property.DataArrayLocator.DataLocatorsProperty Provides a property (getter / setter) for a data locators property (width and height).DataLocator Provides an accessor for a data locator property (URLandInputStream).DataLocator.DataLocatorBuilder<B extends DataLocator.DataLocatorBuilder<B>> Provides a builder for a data locator property.DataLocator.DataLocatorMutator Provides a mutator for a data locator property.DataLocator.DataLocatorProperty Provides a property (getter / setter) for a data locator property (width and height).Numbers TheNumbersinterface defines some constants of interest related to the various number types available. -
Class Summary Class Description Region A text region has a beginning index being included by the region and an end index being excluded by the region and a resulting length. -
Enum Summary Enum Description AckTimeout TheAckTimeoutdefines values used inside a Transmit/Acknowledge (ARQ) processing control flow.Annotator Commonly used characters to be prefixed to annotations' names to distinguish them form element names and the like.AnsiEscapeCode This enumeration contains ANSI Escape-Codes for modifying the appearance of console output to ANSI enabled terminals.Ascii Some ASCII codes used by REFCODES.ORG artifacts.AsciiColorPalette An enumeration for text palette definitions to make it easy working with such default palettes.Binary Some values regarding binary numbers.BitMask The Enum BitMask.BooleanLiterals Some values's literal (String) representation useful when parsing or evaluating texts.CharSet Commonly used char sets.CommandArgPrefix Commonly used prefixes needful for analyzing, parsing or truncating command line arguments and so on.CommandArgPrefixes This enumeration groupsCommandArgPrefixby platform.ConsoleDimension The Enum ConsoleDimension.DaemonLoopSleepTime TheDaemonLoopSleepTimedefined values used inside a control flow.Delimiter Commonly used characters when working with separated values or properties and the like making use of text separator characters .Delimiters TheDelimitersgroupsDelimitervalues belonging somehow together or sharing a similar semantics.Encoding TheEncodingdefine values representing an encoding which are to be passed as argument to according methods.EndOfLine Commonly used characters for EOL markers in texts.EnvironmentVariable EnvironmentVariablefor retrieving some common environment variables with ease.ExitCode Some default exit codes defined for CLI applications.Field FilenameExtension TheFilenameExtensiondefine values useful when working with files or a file-system.Flag A flag can be on or off.Folder TheFolderdefine values useful when working with files or a file-system.Folders TheFoldersdefine values useful when working with folders on a file-system.IoBlockSize TheIoBlockSizedefined values used inside a control flow.IoPollLoopTime TheIoPollLoopTimedefined values used when polling data from I/O, e.g. the file system or via TCP/IP.IoRetryCount TheIoRetryCountdefined values used inside a control flow.IoSleepLoopTime TheIoSleepLoopTimedefined values used inside a control flow.IoTimeout TheIoTimeoutdefines values used inside a IO processing control flow.LatencySleepTime TheLatencySleepTimedefined values used inside a control flow.License Some licensing and copyright information asStringconstants.Literal Some values's literal (String) representation useful when parsing or evaluating texts.LoopExtensionTime TheLoopExtensionTimedefined values used inside a control flow.MarshalParameter MarshalParameterdefines common parameters (parameter is considered the key of a key/value pair) of a given semantics for the according property.MemoryUnit TheMemoryUnitprovides enumerations for common memory units alongside conversions to and from memory size specified in bytes.MoreText Commonly used characters needful for analyzing, parsing or truncating texts.PaddingChar Commonly used characters needful for analyzing, parsing or truncating texts.Port The Enum Port.Prefix Commonly used prefixes needful for analyzing, parsing or truncating texts the like.QuotationMark Commonly used characters needful for analyzing, parsing or truncating texts.RetryCount TheRetryCountdefined values used inside a control flow.RetryLoopCount TheRetryLoopCountdefined values used inside a control flow.ScheduleSleepTime TheScheduleSleepTimedefined values used inside a control flow.Scheme TheSchemedefine values useful when working with files or a file-system.SleepLoopTime TheSleepLoopTimedefined values used inside a control flow.Suffix Commonly used characters needful for analyzing, parsing or truncating texts.SystemProperty SystemPropertydefine values to be used at runtime.Text Commonly used text blocks in the code.TextBorder The Enum TextBorder.Wildcard Commonly used characters needful for analyzing, parsing or truncating texts.