public enum Encoding extends Enum<Encoding> implements org.refcodes.mixin.CodeAccessor<String>
Encoding define values representing an encoding which are to be
passed as argument to according methods.| Enum Constant and Description |
|---|
ISO_8859_1
This encoding is especially useful when having to ensure a 1-to-1 mapping
between bytes and characters.
|
MD5
MD5 hash encoding.
|
UTF_8
Encoding identifying UTF-8 when working with
String objects. |
| Modifier and Type | Method and Description |
|---|---|
String |
getCode() |
static Encoding |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Encoding[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Encoding UTF_8
String objects.public static final Encoding ISO_8859_1
public static final Encoding MD5
public static Encoding[] values()
for (Encoding c : Encoding.values()) System.out.println(c);
public static Encoding valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2017. All rights reserved.