Serializable, Comparable<IoTimeout>, org.refcodes.mixin.MillisecondsAccessorpublic enum IoTimeout extends Enum<IoTimeout> implements org.refcodes.mixin.MillisecondsAccessor
IoTimeout defined values used inside a control flow.org.refcodes.mixin.MillisecondsAccessor.MillisecondsBuilder<B extends org.refcodes.mixin.MillisecondsAccessor.MillisecondsBuilder<B>>, org.refcodes.mixin.MillisecondsAccessor.MillisecondsMutator, org.refcodes.mixin.MillisecondsAccessor.MillisecondsProperty| Modifier and Type | Method | Description |
|---|---|---|
int |
getMilliseconds() |
|
static IoTimeout |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static IoTimeout[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final IoTimeout MIN
public static final IoTimeout NORM
public static final IoTimeout MAX
public static IoTimeout[] values()
for (IoTimeout c : IoTimeout.values()) System.out.println(c);
public static IoTimeout valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic int getMilliseconds()
getMilliseconds in interface org.refcodes.mixin.MillisecondsAccessorCopyright © 2018. All rights reserved.