Serializable, Comparable<LatencySleepTime>, org.refcodes.mixin.MillisecondsAccessorpublic enum LatencySleepTime extends Enum<LatencySleepTime> implements org.refcodes.mixin.MillisecondsAccessor
LatencySleepTime defined values used inside a control flow.org.refcodes.mixin.MillisecondsAccessor.MillisecondsBuilder<B extends org.refcodes.mixin.MillisecondsAccessor.MillisecondsBuilder<B>>, org.refcodes.mixin.MillisecondsAccessor.MillisecondsMutator, org.refcodes.mixin.MillisecondsAccessor.MillisecondsProperty| Modifier and Type | Method | Description |
|---|---|---|
int |
getMilliseconds() |
|
static LatencySleepTime |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static LatencySleepTime[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final LatencySleepTime MIN
public static final LatencySleepTime NORM
public static final LatencySleepTime MAX
public static LatencySleepTime[] values()
for (LatencySleepTime c : LatencySleepTime.values()) System.out.println(c);
public static LatencySleepTime valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic int getMilliseconds()
getMilliseconds in interface org.refcodes.mixin.MillisecondsAccessorCopyright © 2018. All rights reserved.