public enum License extends Enum<License> implements org.refcodes.mixin.TextAccessor
String constants.| Enum Constant and Description |
|---|
COPYRIGHT_NOTE |
LICENSE_NOTE |
REFCODES_LICENSE |
| Modifier and Type | Method and Description |
|---|---|
String |
getText() |
String |
toString() |
static License |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static License[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final License REFCODES_LICENSE
public static final License LICENSE_NOTE
public static final License COPYRIGHT_NOTE
public static License[] values()
for (License c : License.values()) System.out.println(c);
public static License valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getText()
getText in interface org.refcodes.mixin.TextAccessorCopyright © 2018. All rights reserved.