public enum Prefix extends Enum<Prefix> implements org.refcodes.mixin.PrefixAccessor
| Enum Constant and Description |
|---|
ENCRYPTED |
LONG_ARG_OPTION
A command line argument (POSIX) long-option is prefixed with a double
hyphen-minus "--".
|
SHORT_ARG_OPTION
A command line argument (POSIX) short-option is prefixed with a single
hyphen-minus "-".
|
| Modifier and Type | Method and Description |
|---|---|
String |
getPrefix() |
static Prefix |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Prefix[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Prefix ENCRYPTED
public static final Prefix SHORT_ARG_OPTION
public static final Prefix LONG_ARG_OPTION
public static Prefix[] values()
for (Prefix c : Prefix.values()) System.out.println(c);
public static Prefix valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String getPrefix()
getPrefix in interface org.refcodes.mixin.PrefixAccessorCopyright © 2018. All rights reserved.