public enum Prefixes extends Enum<Prefixes>
| Enum Constant and Description |
|---|
ARG_OPTION
All option prefixes as defines by this
PrefixSet interface; being
the Prefix#SHORT_OPTION and the . |
| Modifier and Type | Method and Description |
|---|---|
String[] |
getPrefixes() |
static Prefixes |
valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static Prefixes[] |
values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Prefixes ARG_OPTION
PrefixSet interface; being
the Prefix#SHORT_OPTION and the .public static Prefixes[] values()
for (Prefixes c : Prefixes.values()) System.out.println(c);
public static Prefixes valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic String[] getPrefixes()
Copyright © 2016. All rights reserved.