Serializable, Comparable<Wildcard>, org.refcodes.mixin.CharAccessorpublic enum Wildcard extends Enum<Wildcard> implements org.refcodes.mixin.CharAccessor
| Modifier and Type | Method | Description |
|---|---|---|
char |
getChar() |
|
static Wildcard |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static Wildcard[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final Wildcard CHAR
public static final Wildcard FILE
public static final Wildcard QUERY
public static Wildcard[] values()
for (Wildcard c : Wildcard.values()) System.out.println(c);
public static Wildcard valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullpublic char getChar()
getChar in interface org.refcodes.mixin.CharAccessorCopyright © 2018. All rights reserved.