| Interface | Description |
|---|---|
| AnsiEscapeConsts |
Some defauilt ansi escape codes to be prepended or append
AnsiEscapeConsts.RESET to
your ANSIfied String instances. |
| AsciiColorPaletteConsts |
When working with ASCII art, different characters represent different shades
of grey; here you find constants defining different such palettes.
|
| CharConsts |
Commonly used characters and groups of characters needful for analyzing,
parsing or truncating texts.
|
| CharSetConsts | |
| ControlFlowConsts |
The
ControlFlowConsts define values used inside a control flow. |
| DataArrayLocator |
Provides an accessor for a data locators property (array of
URLs and
InputStreams). |
| DataArrayLocator.DataLocatorsBuilder<B extends DataArrayLocator.DataLocatorsBuilder<B>> |
Provides a builder for a data locators property.
|
| DataArrayLocator.DataLocatorsMutator |
Provides a mutator for a data locators property.
|
| DataArrayLocator.DataLocatorsProperty |
Provides a property (getter / setter) for a data locators property (width
and height).
|
| DataArrayLocator.DataLocatorsPropertyBuilder |
A self sufficient type being a data locators builder and property (width
and height).
|
| DataLocator |
Provides an accessor for a data locator property (
URL and
InputStream). |
| DataLocator.DataLocatorBuilder<B extends DataLocator.DataLocatorBuilder<B>> |
Provides a builder for a data locator property.
|
| DataLocator.DataLocatorMutator |
Provides a mutator for a data locator property.
|
| DataLocator.DataLocatorProperty |
Provides a property (getter / setter) for a data locator property (width
and height).
|
| DataLocator.DataLocatorPropertyBuilder |
A self sufficient type being a data locator builder and property (width
and height).
|
| DateConsts | |
| DelimeterConsts |
Commonly used characters when working with separated values or properties and
the like making use of text separator characters .
|
| EncodingConsts |
The
EncodingConsts define values representing an encoding which are
to be passed as argument to according methods. |
| FieldConsts |
The
FieldConsts are useful when working with fields defined for
external systems such as databases or when working with tables or Map
instances. |
| FileSystemConsts |
The
FileSystemConsts define values useful when working with files or
a file-system. |
| LicenseConsts |
Some licensing and copyright information as
String constants. |
| LiteralConsts |
Some values's literal (
String) representation useful when parsing or
evaluating texts. |
| NumberBaseConsts | |
| QueryConsts |
QueryConsts are useful for query interpreters. |
| ReflectionConsts |
Constans useful when doing reflection kind of things at runtime.
|
| RuntimeConsts |
RuntimeConsts define values to be used at runtime. |
| SystemConsts |
SystemConsts define values to be used with the underlying runtime
system (e.g. operating system); for example names of environment variables
providing dedicated information about the runtime system. |
| TextBorderConsts | |
| TextConsts |
Commonly used text blocks in the code.
|
| Enum | Description |
|---|---|
| Flag |
A flag can be on or off.
|
Copyright © 2016. All rights reserved.