| Class and Description |
|---|
| AnsiEscapeCode
Some default ANSI Escape-Codes to be prepended or append to your ANSIfied
String instances. |
| AsciiColorPalette
An enumeration for text palette definitions to make it easy working with such
default palettes.
|
| Binary
Some values regarding binary numbers.
|
| BitMask
The Enum BitMask.
|
| CharSet
Commonly used char sets.
|
| ConsoleDimension
The Enum ConsoleDimension.
|
| DaemonLoopSleepTime
The
DaemonLoopSleepTime defined values used inside a control flow. |
| DataArrayLocator
Provides an accessor for a data locators property (array of
URLs and
InputStreams). |
| DataArrayLocator.DataLocatorsBuilder
Provides a builder for a data locators property.
|
| DataArrayLocator.DataLocatorsMutator
Provides a mutator for a data locators property.
|
| DataArrayLocator.DataLocatorsProperty
Provides a property (getter / setter) for a data locators property (width
and height).
|
| DataLocator
Provides an accessor for a data locator property (
URL and
InputStream). |
| DataLocator.DataLocatorBuilder
Provides a builder for a data locator property.
|
| DataLocator.DataLocatorMutator
Provides a mutator for a data locator property.
|
| DataLocator.DataLocatorProperty
Provides a property (getter / setter) for a data locator property (width
and height).
|
| Delimiter
Commonly used characters when working with separated values or properties and
the like making use of text separator characters .
|
| Delimiters
The
Delimiters groups Delimiter values belonging somehow
together or sharing a similar semantics. |
| Encoding
The
Encoding define values representing an encoding which are to be
passed as argument to according methods. |
EnvironmentProperty
EnvironmentProperty for retrieving some common environment variables
with ease. |
| Field |
| FileNameExtension
The
FileNameExtension define values useful when working with files or
a file-system. |
| Flag
A flag can be on or off.
|
| Folder
The
Folder define values useful when working with files or a
file-system. |
| Folders
The
Folders define values useful when working with folders on a
file-system. |
| IoBlockSize
The
IoBlockSize defined values used inside a control flow. |
| IoRetryCount
The
IoRetryCount defined values used inside a control flow. |
| IoTimeout
The
IoTimeout defined values used inside a control flow. |
| LatencySleepTime
The
LatencySleepTime defined values used inside a control flow. |
| License
Some licensing and copyright information as
String constants. |
| Literal
Some values's literal (
String) representation useful when parsing or
evaluating texts. |
| Literals
Some values's literal (
String) representation useful when parsing or
evaluating texts. |
| LoopExtensionTime
The
LoopExtensionTime defined values used inside a control flow. |
| LoopSleepTime
The
LoopSleepTime defined values used inside a control flow. |
| Padding
Commonly used characters needful for analyzing, parsing or truncating texts.
|
| Prefix
Commonly used characters needful for analyzing, parsing or truncating texts.
|
| Prefixes
Constant definitions used by the refcodes-console artifact.
|
| Protocol
The
Protocol define values useful when working with files or a
file-system. |
| Proxy
The Enum Proxy.
|
| QuotationMark
Commonly used characters needful for analyzing, parsing or truncating texts.
|
| RetryCount
The
RetryCount defined values used inside a control flow. |
| RetryLoopCount
The
RetryLoopCount defined values used inside a control flow. |
| ScheduleSleepTime
The
ScheduleSleepTime defined values used inside a control flow. |
| Suffix
Commonly used characters needful for analyzing, parsing or truncating texts.
|
SystemProperty
SystemProperty define values to be used at runtime. |
| Text
Commonly used text blocks in the code.
|
| TextBorder
The Enum TextBorder.
|
| Truncate
Commonly used characters needful for analyzing, parsing or truncating texts.
|
| Wildcard
Commonly used characters needful for analyzing, parsing or truncating texts.
|
Copyright © 2017. All rights reserved.